@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2005, 2017 BEA Systems Inc. and others
+ * Copyright (c) 2005, 2018 BEA Systems Inc. and others
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -83,7 +83,7 @@ import com.sun.mirror.util.Types;
 public class BaseProcessorEnv implements AnnotationProcessorEnvironment 
 {
 	static{
-		final AST ast = AST.newAST(AST.JLS9);
+		final AST ast = AST.newAST(AST.JLS10);
 		EMPTY_AST_UNIT = ast.newCompilationUnit();
 	}
 	public static final CompilationUnit EMPTY_AST_UNIT;
@@ -107,6 +107,7 @@ public class BaseProcessorEnv implements AnnotationProcessorEnvironment
 	protected IFile _file;
 	protected final IJavaProject _javaProject;
 	protected final AptProject _aptProject;
+	private final boolean _isTestCode;
 	
 	/**
 	 * Unmodifiable map of processor options, including -A options.
@@ -139,7 +140,7 @@ public class BaseProcessorEnv implements AnnotationProcessorEnvironment
 	public BaseProcessorEnv(CompilationUnit astCompilationUnit,
 						    IFile file,
 						    IJavaProject javaProj,
-							Phase phase )
+							Phase phase, boolean isTestCode )
 	{
 		_astRoot = astCompilationUnit;
 		_file = file;
@@ -149,6 +150,7 @@ public class BaseProcessorEnv implements AnnotationProcessorEnvironment
 		_modelCompUnit2astCompUnit = new HashMap<>();
 		_typeBinding2ModelCompUnit = new HashMap<>();
 		_aptProject = AptPlugin.getAptProject(javaProj);
+		_isTestCode = isTestCode;
 	}
   
 	/**
@@ -168,7 +170,7 @@ public class BaseProcessorEnv implements AnnotationProcessorEnvironment
      * so this will always be up to date with the latest settings.
 	 */
 	private Map<String, String> initOptions(IJavaProject jproj) {
-		Map<String, String> procOptions = AptConfig.getProcessorOptions(jproj);
+		Map<String, String> procOptions = AptConfig.getProcessorOptions(jproj, isTestCode());
 		// options is large enough to include the translated -A options
 		Map<String, String> options = new HashMap<>(procOptions.size() * 2);
 		
@@ -191,20 +193,24 @@ public class BaseProcessorEnv implements AnnotationProcessorEnvironment
 		return Collections.unmodifiableMap(options);
 	}
 
+	@Override
 	public Types getTypeUtils()
     {
 		return new TypesUtil(this);
     }
 	
+	@Override
 	public Declarations getDeclarationUtils()
     {
         return new DeclarationsUtil();
     }
 	
+	@Override
 	public void addListener(AnnotationProcessorListener listener) {
 		throw new UnsupportedOperationException("Not supported!"); //$NON-NLS-1$
 	}
 	
+	@Override
 	public void removeListener(AnnotationProcessorListener listener) {
 		throw new UnsupportedOperationException("Not supported!"); //$NON-NLS-1$
 	}
@@ -216,7 +222,8 @@ public class BaseProcessorEnv implements AnnotationProcessorEnvironment
      * This implementation is different from the API specification in that it does not return
      * all included source types in the universe.
      */
-    public Collection<TypeDeclaration> getTypeDeclarations()
+    @Override
+	public Collection<TypeDeclaration> getTypeDeclarations()
     {
     	final List<ITypeBinding> bindings = getTypeBindings();
 		if( bindings.isEmpty() )
@@ -266,12 +273,14 @@ public class BaseProcessorEnv implements AnnotationProcessorEnvironment
 		}
 	}
     
-    public Collection<TypeDeclaration> getSpecifiedTypeDeclarations()
+    @Override
+	public Collection<TypeDeclaration> getSpecifiedTypeDeclarations()
     {
         return getTypeDeclarations();
     }
     
-    public Collection<Declaration> getDeclarationsAnnotatedWith(AnnotationTypeDeclaration a)
+    @Override
+	public Collection<Declaration> getDeclarationsAnnotatedWith(AnnotationTypeDeclaration a)
     {
     	 final ITypeBinding annotationType = TypesUtil.getTypeBinding(a);
          if( annotationType == null  || !annotationType.isAnnotation()) return Collections.emptyList();
@@ -394,10 +403,12 @@ public class BaseProcessorEnv implements AnnotationProcessorEnvironment
 		return astUnit.findDeclaringNode(binding.getKey());
     }
     
-    public Map<String, String> getOptions(){ return _options; }
+    @Override
+	public Map<String, String> getOptions(){ return _options; }
     
     // does not generate dependencies
-    public TypeDeclaration getTypeDeclaration(String name)
+    @Override
+	public TypeDeclaration getTypeDeclaration(String name)
     {	
     	if( name == null || name.length() == 0 ) return null;
 
@@ -477,11 +488,13 @@ public class BaseProcessorEnv implements AnnotationProcessorEnvironment
 			private IBinding _result = null;
 			private int _kind;
 			
+			@Override
 			public void acceptAST(ICompilationUnit source, CompilationUnit ast) {
 				if( source == unit ){		
 					_modelCompUnit2astCompUnit.put(source, ast);
 				}
 			}
+			@Override
 			public void acceptBinding(String bindingKey, IBinding binding)
 			{
 				if( binding != null ) {
@@ -492,7 +505,7 @@ public class BaseProcessorEnv implements AnnotationProcessorEnvironment
 		}
 
 		final BindingRequestor requestor = new BindingRequestor();
-		final ASTParser parser = ASTParser.newParser(AST.JLS9);
+		final ASTParser parser = ASTParser.newParser(AST.JLS10);
 		parser.setResolveBindings(true);
 		parser.setBindingsRecovery(true);
 		parser.setProject(_javaProject);
@@ -527,6 +540,7 @@ public class BaseProcessorEnv implements AnnotationProcessorEnvironment
 		return getTypeDeclaration(name);
 	}
     
+	@Override
 	public PackageDeclaration getPackage(String name)
 	{
 		if (name == null)
@@ -702,7 +716,7 @@ public class BaseProcessorEnv implements AnnotationProcessorEnvironment
             if( astUnit != null ) return astUnit;
             else{
                 // Note: very expensive operation. we are re-compiling a file with binding information.
-                final ASTParser parser =  ASTParser.newParser(AST.JLS9);
+                final ASTParser parser =  ASTParser.newParser(AST.JLS10);
                 parser.setResolveBindings(true);
         		parser.setBindingsRecovery(true);
                 parser.setSource(unit);
@@ -715,11 +729,13 @@ public class BaseProcessorEnv implements AnnotationProcessorEnvironment
         }
     }
     
-    public Filer getFiler(){ 
+    @Override
+	public Filer getFiler(){ 
     	throw new UnsupportedOperationException("Not supported: the EnvironmentFactory API is for type system navigation only"); //$NON-NLS-1$
     }    
 
-    public Messager getMessager(){ 
+    @Override
+	public Messager getMessager(){ 
     	throw new UnsupportedOperationException("Not supported: the EnvironmentFactory API is for type system navigation only"); //$NON-NLS-1$
     }
     
@@ -821,6 +837,7 @@ public class BaseProcessorEnv implements AnnotationProcessorEnvironment
 			this.parseUnits = parseUnits;
 		}
 		
+		@Override
 		public void acceptAST(ICompilationUnit source, CompilationUnit ast) {
 			for( int i=0, len = asts.length; i<len; i++ ){
 				if( source == parseUnits[i] ){
@@ -848,7 +865,7 @@ public class BaseProcessorEnv implements AnnotationProcessorEnvironment
 		String bogusKey = BindingKey.createTypeBindingKey("java.lang.Object"); //$NON-NLS-1$
 		String[] keys = new String[] {bogusKey};
 
-		ASTParser p = ASTParser.newParser( AST.JLS9 );
+		ASTParser p = ASTParser.newParser( AST.JLS10 );
 		p.setResolveBindings(true);
 		p.setBindingsRecovery(true);
 		p.setProject( javaProject );
@@ -870,6 +887,7 @@ public class BaseProcessorEnv implements AnnotationProcessorEnvironment
 		class CompilationUnitRequestor extends ASTRequestor
 		{	
 			CompilationUnit domUnit = EMPTY_AST_UNIT;
+			@Override
 			public void acceptAST(ICompilationUnit source, CompilationUnit ast) {
 				if( source == compilationUnit )
 					domUnit = ast;			
@@ -877,7 +895,7 @@ public class BaseProcessorEnv implements AnnotationProcessorEnvironment
 		}
 		
 		CompilationUnitRequestor requestor = new CompilationUnitRequestor();
-		ASTParser p = ASTParser.newParser( AST.JLS9 );
+		ASTParser p = ASTParser.newParser( AST.JLS10 );
 		p.setResolveBindings(true);
 		p.setBindingsRecovery(true);
 		p.setProject( javaProject );
@@ -993,4 +1011,5 @@ public class BaseProcessorEnv implements AnnotationProcessorEnvironment
     public IProject         getProject(){ return _javaProject.getProject(); }
 	public IJavaProject		getJavaProject(){ return _javaProject; }
 	public AptProject		getAptProject(){ return _aptProject; }
+	public boolean isTestCode() { return _isTestCode; }
 }
