@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2007, 2017 IBM Corporation and others.
+ * Copyright (c) 2007, 2018 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -29,7 +29,6 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
-import java.util.Map.Entry;
 
 import javax.annotation.processing.Processor;
 import javax.lang.model.SourceVersion;
@@ -126,7 +125,6 @@ public class EclipseCompilerImpl extends Main {
 	public CompilationUnit[] getCompilationUnits() {
 		// This method is largely a copy of Main#getCompilationUnits()
 		if (this.compilationUnits == null) return EclipseCompilerImpl.NO_UNITS;
-		Map<String,CompilationUnit> pathToModCU = new HashMap<>();
 		HashtableOfObject knownFileNames = new HashtableOfObject();
 		ArrayList<CompilationUnit> units = new ArrayList<>();
 		for (int round = 0; round < 2; round++) {
@@ -160,21 +158,6 @@ public class EclipseCompilerImpl extends Main {
 						};
 						units.add(cu);
 						this.javaFileObjectMap.put(cu, javaFileObject);
-						if (isModuleInfo) {
-							int lastSlash = CharOperation.lastIndexOf(File.separatorChar, cu.fileName);
-							if (lastSlash != -1) {
-								pathToModCU.put(String.valueOf(CharOperation.subarray(cu.fileName, 0, lastSlash)), cu);
-							}
-						} else {
-							for (Entry<String, CompilationUnit> entry : pathToModCU.entrySet()) {
-								Path modPath = Paths.get(entry.getKey());
-								Path cuPath = Paths.get(name);
-								while (cuPath != null && cuPath.startsWith(modPath)) {
-									cu.setModule(entry.getValue());
-									break;
-								}
-							}
-						}
 				}
 				i++;
 			}
@@ -221,8 +204,9 @@ public class EclipseCompilerImpl extends Main {
 					final int columnNumber) {
 
 				DiagnosticListener<? super JavaFileObject> diagListener = EclipseCompilerImpl.this.diagnosticListener;
+				Diagnostic<JavaFileObject> diagnostic = null;
 				if (diagListener != null) {
-					diagListener.report(new Diagnostic<JavaFileObject>() {
+					diagnostic = new Diagnostic<JavaFileObject>() {
 						@Override
 						public String getCode() {
 							return Integer.toString(problemId);
@@ -275,9 +259,13 @@ public class EclipseCompilerImpl extends Main {
 						public long getStartPosition() {
 							return startPosition;
 						}
-					});
+					};
 				}
-				return super.createProblem(originatingFileName, problemId, problemArguments, messageArguments, severity, startPosition, endPosition, lineNumber, columnNumber);
+				CategorizedProblem problem = super.createProblem(originatingFileName, problemId, problemArguments, messageArguments, severity, startPosition, endPosition, lineNumber, columnNumber);
+				if (problem instanceof DefaultProblem && diagnostic != null) {
+					return new Jsr199ProblemWrapper((DefaultProblem) problem, diagnostic, diagListener);
+				}
+				return problem;
 			}
 			@Override
 			public CategorizedProblem createProblem(
@@ -293,8 +281,9 @@ public class EclipseCompilerImpl extends Main {
 					final int columnNumber) {
 
 				DiagnosticListener<? super JavaFileObject> diagListener = EclipseCompilerImpl.this.diagnosticListener;
+				Diagnostic<JavaFileObject> diagnostic = null;
 				if (diagListener != null) {
-					diagListener.report(new Diagnostic<JavaFileObject>() {
+					diagnostic = new Diagnostic<JavaFileObject>() {
 						@Override
 						public String getCode() {
 							return Integer.toString(problemId);
@@ -350,9 +339,13 @@ public class EclipseCompilerImpl extends Main {
 						public long getStartPosition() {
 							return startPosition;
 						}
-					});
+					};
 				}
-				return super.createProblem(originatingFileName, problemId, problemArguments, elaborationID, messageArguments, severity, startPosition, endPosition, lineNumber, columnNumber);
+				CategorizedProblem problem = super.createProblem(originatingFileName, problemId, problemArguments, elaborationID, messageArguments, severity, startPosition, endPosition, lineNumber, columnNumber);
+				if (problem instanceof DefaultProblem && diagnostic != null) {
+					return new Jsr199ProblemWrapper((DefaultProblem) problem, diagnostic, diagListener);
+				}
+				return problem;
 			}
 		};
 	}
@@ -522,7 +515,9 @@ public class EclipseCompilerImpl extends Main {
 						Classpath classpath = FileSystem.getClasspath(
 								file.getAbsolutePath(),
 								null,
-								null, this.options);
+								null, 
+								this.options,
+								this.releaseVersion);
 							if (classpath != null) {
 								fileSystemClasspaths.add(classpath);
 								havePlatformPaths = true;
@@ -566,7 +561,9 @@ public class EclipseCompilerImpl extends Main {
 					Classpath classpath = FileSystem.getClasspath(
 							file.getAbsolutePath(),
 							null,
-							null, this.options);
+							null, 
+							this.options,
+							this.releaseVersion);
 					if (classpath != null) {
 						fileSystemClasspaths.add(classpath);
 					}
@@ -578,7 +575,9 @@ public class EclipseCompilerImpl extends Main {
 					Classpath classpath = FileSystem.getClasspath(
 						file.getAbsolutePath(),
 						null,
-						null, this.options);
+						null, 
+						this.options,
+						this.releaseVersion);
 					if (classpath != null) {
 						fileSystemClasspaths.add(classpath);
 						haveClassPaths = true;
@@ -589,21 +588,23 @@ public class EclipseCompilerImpl extends Main {
 				try {
 					Iterable<? extends Path> locationAsPaths = standardJavaFileManager.getLocationAsPaths(StandardLocation.MODULE_SOURCE_PATH);
 					if (locationAsPaths != null) {
+						StringBuilder builder = new StringBuilder();
 						for (Path path : locationAsPaths) {
-							ArrayList<Classpath> modulepaths = handleModuleSourcepath(path.toFile().getCanonicalPath());
-							for (Classpath classpath : modulepaths) {
-								Collection<String> moduleNames = classpath.getModuleNames(null);
-								for (String modName : moduleNames) {
-									Path p = Paths.get(classpath.getPath());
-									standardJavaFileManager.setLocationForModule(StandardLocation.MODULE_SOURCE_PATH, modName, 
-											Collections.singletonList(p));
-									p = Paths.get(classpath.getDestinationPath());
-									standardJavaFileManager.setLocationForModule(StandardLocation.CLASS_OUTPUT, modName, 
-											Collections.singletonList(p));
-								}
-							}
-							fileSystemClasspaths.addAll(modulepaths);
+							// Append all of them
+							builder.append(path.toFile().getCanonicalPath());
+							builder.append(File.pathSeparator);
 						}
+						ArrayList<Classpath> modulepaths = handleModuleSourcepath(builder.toString());
+						for (Classpath classpath : modulepaths) {
+							Collection<String> moduleNames = classpath.getModuleNames(null);
+							for (String modName : moduleNames) {
+								Path p = Paths.get(classpath.getPath());
+								standardJavaFileManager.setLocationForModule(StandardLocation.MODULE_SOURCE_PATH, modName, 
+										Collections.singletonList(p));
+								p = Paths.get(classpath.getDestinationPath());
+							}
+						}
+						fileSystemClasspaths.addAll(modulepaths);
 					}
 				} catch (Exception e) {
 					// TODO: Revisit when JRE 9 no longer throws IllegalStateException for getLocation.
@@ -694,7 +695,7 @@ public class EclipseCompilerImpl extends Main {
 			Iterator iterator = this.extraProblems.iterator(); iterator.hasNext(); ) {
 			final CategorizedProblem problem = (CategorizedProblem) iterator.next();
 			if (this.diagnosticListener != null) {
-				this.diagnosticListener.report(new Diagnostic<JavaFileObject>() {
+				Diagnostic<JavaFileObject> diagnostic = new Diagnostic<JavaFileObject>() {
 					@Override
 					public String getCode() {
 						return null;
@@ -760,8 +761,105 @@ public class EclipseCompilerImpl extends Main {
 					public long getStartPosition() {
 						return getPosition();
 					}
-				});
+				};
+				this.diagnosticListener.report(diagnostic);
 			}
 		}
 	}
+	class Jsr199ProblemWrapper extends DefaultProblem {
+
+		DefaultProblem original;
+		DiagnosticListener<? super JavaFileObject> listener;
+		Diagnostic<JavaFileObject> diagnostic;
+
+		public Jsr199ProblemWrapper(DefaultProblem original, Diagnostic<JavaFileObject> diagnostic, DiagnosticListener<? super JavaFileObject> listener) {
+			super(original.getOriginatingFileName(),
+					original.getMessage(),
+					original.getID(),
+					original.getArguments(),
+					original.severity,
+					original.getSourceStart(),
+					original.getSourceEnd(),
+					original.getSourceLineNumber(),
+					original.column);
+			this.original = original;
+			this.listener = listener;
+			this.diagnostic = diagnostic;
+		}
+		@Override
+		public void reportError() {
+			this.listener.report(this.diagnostic);
+		}
+
+		@Override
+		public String[] getArguments() {
+			return this.original.getArguments();
+		}
+
+		@Override
+		public int getID() {
+			return this.original.getID();
+		}
+
+		@Override
+		public String getMessage() {
+			return this.original.getMessage();
+		}
+
+		@Override
+		public char[] getOriginatingFileName() {
+			return this.original.getOriginatingFileName();
+		}
+
+		@Override
+		public int getSourceEnd() {
+			return this.original.getSourceEnd();
+		}
+
+		@Override
+		public int getSourceLineNumber() {
+			return this.original.getSourceLineNumber();
+		}
+
+		@Override
+		public int getSourceStart() {
+			return this.original.getSourceStart();
+		}
+
+		@Override
+		public boolean isError() {
+			return this.original.isError();
+		}
+
+		@Override
+		public boolean isWarning() {
+			return this.original.isWarning();
+		}
+
+		@Override
+		public void setSourceEnd(int sourceEnd) {
+			this.original.setSourceEnd(sourceEnd);
+		}
+
+		@Override
+		public void setSourceLineNumber(int lineNumber) {
+			this.original.setSourceLineNumber(lineNumber);
+		}
+
+		@Override
+		public void setSourceStart(int sourceStart) {
+			this.original.setSourceStart(sourceStart);
+		}
+
+		@Override
+		public int getCategoryID() {
+			return this.original.getCategoryID();
+		}
+
+		@Override
+		public String getMarkerType() {
+			return this.original.getMarkerType();
+		}
+		
+	}
 }
