@@ -1,12 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2018 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
- *
+ * 
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Jesper Steen Møller <jesper@selskabet.org> - contributions for:	
+ *         Bug 531046: [10] ICodeAssist#codeSelect support for 'var'
  *******************************************************************************/
 package org.eclipse.jdt.internal.codeassist.select;
 
@@ -76,8 +78,15 @@ public class SelectionParser extends AssistParser {
 	protected static final int K_INSIDE_RETURN_STATEMENT = SELECTION_PARSER + 2; // whether we are between the keyword 'return' and the end of a return statement
 	protected static final int K_CAST_STATEMENT = SELECTION_PARSER + 3; // whether we are between ')' and the end of a cast statement
 
-	// https://bugs.eclipse.org/bugs/show_bug.cgi?id=476693
-	private boolean selectionNodeFound;
+	/* https://bugs.eclipse.org/bugs/show_bug.cgi?id=476693
+	 * https://bugs.eclipse.org/bugs/show_bug.cgi?id=515758
+	 * Records whether and when we found an invocation being selected:
+	 * 0: not found
+	 * 1: found just now
+	 * 2...: inside block (lambda body) within the invocation found before
+	 * Rationale: we really need to complete parsing the invocation for resolving to succeed.
+	 */
+	private int selectionNodeFoundLevel = 0;
 	public ASTNode assistNodeParent; // the parent node of assist node
 
 	/* public fields */
@@ -90,6 +99,7 @@ public SelectionParser(ProblemReporter problemReporter) {
 	super(problemReporter);
 	this.javadocParser.checkDocComment = true;
 }
+@Override
 public char[] assistIdentifier(){
 	return ((SelectionScanner)this.scanner).selectionIdentifier;
 }
@@ -217,6 +227,7 @@ private boolean checkRecoveredType() {
 	}
 	return false;
 }
+@Override
 protected void classInstanceCreation(boolean hasClassBody) {
 
 	// ClassInstanceCreationExpression ::= 'new' ClassType '(' ArgumentListopt ')' ClassBodyopt
@@ -278,6 +289,7 @@ protected void classInstanceCreation(boolean hasClassBody) {
 		super.classInstanceCreation(hasClassBody);
 	}
 }
+@Override
 protected void consumeArrayCreationExpressionWithoutInitializer() {
 	// ArrayCreationWithoutArrayInitializer ::= 'new' PrimitiveType DimWithOrWithOutExprs
 	// ArrayCreationWithoutArrayInitializer ::= 'new' ClassOrInterfaceType DimWithOrWithOutExprs
@@ -293,6 +305,7 @@ protected void consumeArrayCreationExpressionWithoutInitializer() {
 		this.isOrphanCompletionNode = true;
 	}
 }
+@Override
 protected void consumeArrayCreationExpressionWithInitializer() {
 	// ArrayCreationWithArrayInitializer ::= 'new' ClassOrInterfaceType DimWithOrWithOutExprs ArrayInitializer
 
@@ -307,30 +320,37 @@ protected void consumeArrayCreationExpressionWithInitializer() {
 		this.isOrphanCompletionNode = true;
 	}
 }
+@Override
 protected void consumeCastExpressionLL1() {
 	popElement(K_CAST_STATEMENT);
 	super.consumeCastExpressionLL1();
 }
+@Override
 protected void consumeCastExpressionLL1WithBounds() {
 	popElement(K_CAST_STATEMENT);
 	super.consumeCastExpressionLL1WithBounds();
 }
+@Override
 protected void consumeCastExpressionWithGenericsArray() {
 	popElement(K_CAST_STATEMENT);
 	super.consumeCastExpressionWithGenericsArray();
 }
+@Override
 protected void consumeCastExpressionWithNameArray() {
 	popElement(K_CAST_STATEMENT);
 	super.consumeCastExpressionWithNameArray();
 }
+@Override
 protected void consumeCastExpressionWithPrimitiveType() {
 	popElement(K_CAST_STATEMENT);
 	super.consumeCastExpressionWithPrimitiveType();
 }
+@Override
 protected void consumeCastExpressionWithQualifiedGenericsArray() {
 	popElement(K_CAST_STATEMENT);
 	super.consumeCastExpressionWithQualifiedGenericsArray();
 }
+@Override
 protected void consumeCatchFormalParameter() {
 	if (this.indexOfAssistIdentifier() < 0) {
 		super.consumeCatchFormalParameter();
@@ -387,6 +407,7 @@ protected void consumeCatchFormalParameter() {
 		this.listLength++;
 	}
 }
+@Override
 protected void consumeClassInstanceCreationExpressionQualifiedWithTypeArguments() {
 	// ClassInstanceCreationExpression ::= Primary '.' 'new' TypeArguments SimpleName '(' ArgumentListopt ')' ClassBodyopt
 	// ClassInstanceCreationExpression ::= ClassInstanceCreationExpressionName 'new' TypeArguments SimpleName '(' ArgumentListopt ')' ClassBodyopt
@@ -452,6 +473,7 @@ protected void consumeClassInstanceCreationExpressionQualifiedWithTypeArguments(
 	this.expressionStack[this.expressionPtr] = qae;
 	qae.sourceStart = qae.enclosingInstance.sourceStart;
 }
+@Override
 protected void consumeClassInstanceCreationExpressionWithTypeArguments() {
 	// ClassInstanceCreationExpression ::= 'new' TypeArguments ClassType '(' ArgumentListopt ')' ClassBodyopt
 	AllocationExpression alloc;
@@ -509,6 +531,7 @@ protected void consumeClassInstanceCreationExpressionWithTypeArguments() {
 		super.consumeClassInstanceCreationExpressionWithTypeArguments();
 	}
 }
+@Override
 protected void consumeEnterAnonymousClassBody(boolean qualified) {
 	// EnterAnonymousClassBody ::= $empty
 
@@ -580,6 +603,7 @@ protected void consumeEnterAnonymousClassBody(boolean qualified) {
 		this.lastIgnoredToken = -1;
 	}
 }
+@Override
 protected void consumeEnterVariable() {
 	// EnterVariable ::= $empty
 	// do nothing by default
@@ -588,7 +612,7 @@ protected void consumeEnterVariable() {
 
 	AbstractVariableDeclaration variable = (AbstractVariableDeclaration) this.astStack[this.astPtr];
 	if (variable.type == this.assistNode){
-		if (!this.diet){
+		if (!this.diet && ! variable.type.isTypeNameVar(null)) {
 			this.restartRecovery	= true;	// force to restart in recovery mode
 			this.lastIgnoredToken = -1;
 		}
@@ -596,20 +620,25 @@ protected void consumeEnterVariable() {
 	}
 }
 
+@Override
 protected void consumeExitVariableWithInitialization() {
 	super.consumeExitVariableWithInitialization();
 
 	// does not keep the initialization if selection is not inside
 	AbstractVariableDeclaration variable = (AbstractVariableDeclaration) this.astStack[this.astPtr];
-	int start = variable.initialization.sourceStart;
-	int end =  variable.initialization.sourceEnd;
-	if ((this.selectionStart < start) &&  (this.selectionEnd < start) ||
-			(this.selectionStart > end) && (this.selectionEnd > end)) {
+	int start = variable.declarationSourceStart;
+	int end =  variable.declarationSourceEnd;
+	// Keep the initialization intact, because that's the only way we are going to know the type
+	if (!variable.type.isTypeNameVar(null)) {
+		if ((this.selectionStart < start) &&  (this.selectionEnd < start) ||
+				(this.selectionStart > end) && (this.selectionEnd > end)) {
 			variable.initialization = null;
+		}
 	}
 	triggerRecoveryUponLambdaClosure(variable, false);
 }
 
+@Override
 protected void consumeFieldAccess(boolean isSuperAccess) {
 	// FieldAccess ::= Primary '.' 'Identifier'
 	// FieldAccess ::= 'super' '.' 'Identifier'
@@ -641,6 +670,7 @@ protected void consumeFieldAccess(boolean isSuperAccess) {
 	}
 	this.isOrphanCompletionNode = true;
 }
+@Override
 protected void consumeFormalParameter(boolean isVarArgs) {
 	if (this.indexOfAssistIdentifier() < 0) {
 		super.consumeFormalParameter(isVarArgs);
@@ -734,22 +764,27 @@ protected void consumeFormalParameter(boolean isVarArgs) {
 		this.listLength++;
 	}
 }
+@Override
 protected void consumeInsideCastExpression() {
 	super.consumeInsideCastExpression();
 	pushOnElementStack(K_CAST_STATEMENT);
 }
+@Override
 protected void consumeInsideCastExpressionLL1() {
 	super.consumeInsideCastExpressionLL1();
 	pushOnElementStack(K_CAST_STATEMENT);
 }
+@Override
 protected void consumeInsideCastExpressionLL1WithBounds() {
 	super.consumeInsideCastExpressionLL1WithBounds();
 	pushOnElementStack(K_CAST_STATEMENT);
 }
+@Override
 protected void consumeInsideCastExpressionWithQualifiedGenerics() {
 	super.consumeInsideCastExpressionWithQualifiedGenerics();
 	pushOnElementStack(K_CAST_STATEMENT);
 }
+@Override
 protected void consumeInstanceOfExpression() {
 	if (indexOfAssistIdentifier() < 0) {
 		super.consumeInstanceOfExpression();
@@ -760,6 +795,7 @@ protected void consumeInstanceOfExpression() {
 		this.lastIgnoredToken = -1;
 	}
 }
+@Override
 protected void consumeInstanceOfExpressionWithName() {
 	if (indexOfAssistIdentifier() < 0) {
 		super.consumeInstanceOfExpressionWithName();
@@ -797,6 +833,7 @@ protected void consumeReferenceExpression(ReferenceExpression referenceExpressio
 	super.consumeReferenceExpression(referenceExpression);
 }
 
+@Override
 protected void consumeLocalVariableDeclarationStatement() {
 	super.consumeLocalVariableDeclarationStatement();
 
@@ -809,22 +846,40 @@ protected void consumeLocalVariableDeclarationStatement() {
 			this.lastIgnoredToken = -1;
 		}
 	}
-	if (this.selectionNodeFound) {
-		this.restartRecovery = true;
-	}
+	checkRestartRecovery();
 }
+@Override
 protected void consumeAssignment() {
 	super.consumeAssignment();
-	if (this.selectionNodeFound) {
-		this.restartRecovery = true;
-	}
+	checkRestartRecovery();
 }
+@Override
 protected void consumeBlockStatement() {
 	super.consumeBlockStatement();
-	if (this.selectionNodeFound) {
-		this.restartRecovery = true;
+	checkRestartRecovery();
+}
+protected void checkRestartRecovery() {
+	if (this.selectionNodeFoundLevel > 0) {
+		if (--this.selectionNodeFoundLevel == 0)
+			this.restartRecovery = true;
 	}
 }
+
+@Override
+protected void consumeOpenBlock() {
+	super.consumeOpenBlock();
+	if (this.selectionNodeFoundLevel > 0)
+		this.selectionNodeFoundLevel++;
+}
+
+@Override
+protected void consumeBlock() {
+	super.consumeBlock();
+	if (this.selectionNodeFoundLevel > 0)
+		this.selectionNodeFoundLevel--;
+}
+
+@Override
 protected void consumeMarkerAnnotation(boolean isTypeAnnotation) {
 	int index;
 
@@ -876,6 +931,7 @@ protected void consumeMarkerAnnotation(boolean isTypeAnnotation) {
 		pushOnExpressionStack(markerAnnotation);
 	}
 }
+@Override
 protected void consumeMemberValuePair() {
 	if (this.indexOfAssistIdentifier() < 0) {
 		super.consumeMemberValuePair();
@@ -897,6 +953,7 @@ protected void consumeMemberValuePair() {
 
 
 }
+@Override
 protected void consumeMethodInvocationName() {
 	// MethodInvocation ::= Name '(' ArgumentListopt ')'
 
@@ -945,10 +1002,12 @@ protected void consumeMethodInvocationName() {
 		this.lastIgnoredToken = -1;
 	} else {
 		pushOnExpressionStack(new Expression(){
+			@Override
 			public TypeBinding resolveType(BlockScope scope) {
 				constructorCall.resolve(scope);
 				return null;
 			}
+			@Override
 			public StringBuffer printExpression(int indent, StringBuffer output) {
 				return output;
 			}
@@ -958,6 +1017,7 @@ protected void consumeMethodInvocationName() {
 	this.lastCheckPoint = constructorCall.sourceEnd + 1;
 	this.isOrphanCompletionNode = true;
 }
+@Override
 protected void consumeMethodInvocationPrimary() {
 	//optimize the push/pop
 	//MethodInvocation ::= Primary '.' 'Identifier' '(' ArgumentListopt ')'
@@ -994,10 +1054,12 @@ protected void consumeMethodInvocationPrimary() {
 		this.lastIgnoredToken = -1;
 	} else {
 		pushOnExpressionStack(new Expression(){
+			@Override
 			public TypeBinding resolveType(BlockScope scope) {
 				constructorCall.resolve(scope);
 				return null;
 			}
+			@Override
 			public StringBuffer printExpression(int indent, StringBuffer output) {
 				return output;
 			}
@@ -1008,6 +1070,7 @@ protected void consumeMethodInvocationPrimary() {
 	this.lastCheckPoint = constructorCall.sourceEnd + 1;
 	this.isOrphanCompletionNode = true;
 }
+@Override
 protected void consumeNormalAnnotation(boolean isTypeAnnotation) {
 	int index;
 
@@ -1067,6 +1130,7 @@ protected void consumeNormalAnnotation(boolean isTypeAnnotation) {
 		pushOnExpressionStack(normalAnnotation);
 	}
 }
+@Override
 protected void consumeSingleMemberAnnotation(boolean isTypeAnnotation) {
 	int index;
 
@@ -1120,6 +1184,7 @@ protected void consumeSingleMemberAnnotation(boolean isTypeAnnotation) {
 		pushOnExpressionStack(singleMemberAnnotation);
 	}
 }
+@Override
 protected void consumeStaticImportOnDemandDeclarationName() {
 	// TypeImportOnDemandDeclarationName ::= 'import' 'static' Name '.' '*'
 	/* push an ImportRef build from the last name
@@ -1174,6 +1239,7 @@ protected void consumeStaticImportOnDemandDeclarationName() {
 		this.restartRecovery = true; // used to avoid branching back into the regular automaton
 	}
 }
+@Override
 protected void consumeToken(int token) {
 	super.consumeToken(token);
 
@@ -1203,6 +1269,7 @@ protected void consumeToken(int token) {
 		}
 	}
 }
+@Override
 protected void consumeTypeImportOnDemandDeclarationName() {
 	// TypeImportOnDemandDeclarationName ::= 'import' Name '.' '*'
 	/* push an ImportRef build from the last name
@@ -1257,12 +1324,15 @@ protected void consumeTypeImportOnDemandDeclarationName() {
 		this.restartRecovery = true; // used to avoid branching back into the regular automaton
 	}
 }
+@Override
 protected SelectionParser createSnapShotParser() {
 	return new SelectionParser(this.problemReporter);
 }
+@Override
 public ImportReference createAssistPackageVisibilityReference(char[][] tokens, long[] positions){
 	return new SelectionOnPackageVisibilityReference(tokens, positions);
 }
+@Override
 public ImportReference createAssistImportReference(char[][] tokens, long[] positions, int mod){
 	return new SelectionOnImportReference(tokens, positions, mod);
 }
@@ -1271,12 +1341,15 @@ public ModuleDeclaration createAssistModuleDeclaration(CompilationResult compila
 		long[] positions) {
 	return new SelectionOnModuleDeclaration(compilationResult, tokens, positions);
 }
+@Override
 public ImportReference createAssistPackageReference(char[][] tokens, long[] positions){
 	return new SelectionOnPackageReference(tokens, positions);
 }
+@Override
 protected JavadocParser createJavadocParser() {
 	return new SelectionJavadocParser(this);
 }
+@Override
 protected LocalDeclaration createLocalDeclaration(char[] assistName,int sourceStart,int sourceEnd) {
 	if (this.indexOfAssistIdentifier() < 0) {
 		return super.createLocalDeclaration(assistName, sourceStart, sourceEnd);
@@ -1287,29 +1360,35 @@ protected LocalDeclaration createLocalDeclaration(char[] assistName,int sourceSt
 		return local;
 	}
 }
+@Override
 public NameReference createQualifiedAssistNameReference(char[][] previousIdentifiers, char[] assistName, long[] positions){
 	return new SelectionOnQualifiedNameReference(
 					previousIdentifiers,
 					assistName,
 					positions);
 }
+@Override
 public TypeReference createQualifiedAssistTypeReference(char[][] previousIdentifiers, char[] assistName, long[] positions){
 	return new SelectionOnQualifiedTypeReference(
 					previousIdentifiers,
 					assistName,
 					positions);
 }
+@Override
 public TypeReference createParameterizedQualifiedAssistTypeReference(
 		char[][] tokens, TypeReference[][] typeArguments, char[] assistname, TypeReference[] assistTypeArguments, long[] positions) {
 	return new SelectionOnParameterizedQualifiedTypeReference(tokens, assistname, typeArguments, assistTypeArguments, positions);
 
 }
+@Override
 public NameReference createSingleAssistNameReference(char[] assistName, long position) {
 	return new SelectionOnSingleNameReference(assistName, position);
 }
+@Override
 public TypeReference createSingleAssistTypeReference(char[] assistName, long position) {
 	return new SelectionOnSingleTypeReference(assistName, position);
 }
+@Override
 public TypeReference createParameterizedSingleAssistTypeReference(TypeReference[] typeArguments, char[] assistName, long position) {
 	return new SelectionOnParameterizedSingleTypeReference(assistName, typeArguments, position);
 }
@@ -1323,6 +1402,7 @@ public CompilationUnitDeclaration dietParse(ICompilationUnit sourceUnit, Compila
 	selectionScanner.selectionEnd = end;
 	return this.dietParse(sourceUnit, compilationResult);
 }
+@Override
 protected NameReference getUnspecifiedReference(boolean rejectTypeAnnotations) {
 	/* build a (unspecified) NameReference which may be qualified*/
 
@@ -1405,6 +1485,7 @@ protected NameReference getUnspecifiedReference(boolean rejectTypeAnnotations) {
  * qualified name reference, then create a CompletionOnQualifiedNameReference
  * instead.
  */
+@Override
 protected NameReference getUnspecifiedReferenceOptimized() {
 
 	int index = indexOfAssistIdentifier();
@@ -1419,9 +1500,11 @@ protected NameReference getUnspecifiedReferenceOptimized() {
 	}
 	return reference;
 }
+@Override
 public void initializeScanner(){
 	this.scanner = new SelectionScanner(this.options.sourceLevel);
 }
+@Override
 public ReferenceExpression newReferenceExpression() {
 	char[] selector = this.identifierStack[this.identifierPtr];
 	if (selector != assistIdentifier()){
@@ -1431,6 +1514,7 @@ public ReferenceExpression newReferenceExpression() {
 	this.assistNode = referenceExpression;
 	return referenceExpression;
 }
+@Override
 protected MessageSend newMessageSend() {
 	// '(' ArgumentListopt ')'
 	// the arguments are on the expression stack
@@ -1454,13 +1538,14 @@ protected MessageSend newMessageSend() {
 	if (!this.diet){
 		// Don't restart recovery, not yet, until variable decl statement has been consumed.
 		// This is to ensure chained method invocations are taken into account for resolution.
-		this.selectionNodeFound = true;
+		this.selectionNodeFoundLevel = 1;
 		this.lastIgnoredToken = -1;
 	}
 
 	this.isOrphanCompletionNode = true;
 	return messageSend;
 }
+@Override
 protected MessageSend newMessageSendWithTypeArguments() {
 	char[] selector = this.identifierStack[this.identifierPtr];
 	if (selector != assistIdentifier()){
@@ -1481,13 +1566,14 @@ protected MessageSend newMessageSendWithTypeArguments() {
 	if (!this.diet){
 		// Don't restart recovery, not yet, until variable decl statement has been consumed.
 		// This is to ensure chained method invocations are taken into account for resolution.
-		this.selectionNodeFound = true;
+		this.selectionNodeFoundLevel = 1;
 		this.lastIgnoredToken = -1;
 	}
 
 	this.isOrphanCompletionNode = true;
 	return messageSend;
 }
+@Override
 public CompilationUnitDeclaration parse(ICompilationUnit sourceUnit, CompilationResult compilationResult, int start, int end) {
 
 	if (end == -1) return super.parse(sourceUnit, compilationResult, start, end);
@@ -1508,6 +1594,7 @@ public CompilationUnitDeclaration parse(ICompilationUnit sourceUnit, Compilation
  * Move checkpoint location, reset internal stacks and
  * decide which grammar goal is activated.
  */
+@Override
 protected int resumeAfterRecovery() {
 
 	/* if reached assist node inside method body, but still inside nested type,
@@ -1540,12 +1627,14 @@ protected int resumeAfterRecovery() {
 public void selectionIdentifierCheck(){
 	if (checkRecoveredType()) return;
 }
+@Override
 public void setAssistIdentifier(char[] assistIdent){
 	((SelectionScanner)this.scanner).selectionIdentifier = assistIdent;
 }
 /*
  * Update recovery state based on current parser/scanner state
  */
+@Override
 protected void updateRecoveryState() {
 
 	/* expose parser state to recovery state */
@@ -1567,6 +1656,7 @@ protected void updateRecoveryState() {
 	*/
 	recoveryTokenCheck();
 }
+@Override
 protected Argument typeElidedArgument() {
 	char[] selector = this.identifierStack[this.identifierPtr];
 	if (selector != assistIdentifier()){
@@ -1587,6 +1677,7 @@ protected Argument typeElidedArgument() {
 	this.assistNode = argument;
 	return argument;
 }
+@Override
 public  String toString() {
 	String s = Util.EMPTY_STRING;
 	s = s + "elementKindStack : int[] = {"; //$NON-NLS-1$
