@@ -1,10 +1,10 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2018 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
- *
+ * 
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *     Stephan Herrmann - Contributions for
@@ -76,6 +76,7 @@ public TypeDeclaration(CompilationResult compilationResult){
 /*
  *	We cause the compilation task to abort to a given extent.
  */
+@Override
 public void abort(int abortLevel, CategorizedProblem problem) {
 	switch (abortLevel) {
 		case AbortCompilation :
@@ -197,6 +198,7 @@ public MethodDeclaration addMissingAbstractMethodFor(MethodBinding methodBinding
  *	Flow analysis for a local innertype
  *
  */
+@Override
 public FlowInfo analyseCode(BlockScope currentScope, FlowContext flowContext, FlowInfo flowInfo) {
 	if (this.ignoreFurtherInvestigation)
 		return flowInfo;
@@ -306,6 +308,7 @@ public boolean checkConstructors(Parser parser) {
 	return hasConstructor;
 }
 
+@Override
 public CompilationResult compilationResult() {
 	return this.compilationResult;
 }
@@ -511,6 +514,7 @@ public TypeDeclaration declarationOfType(char[][] typeName) {
 	return null;
 }
 
+@Override
 public CompilationUnitDeclaration getCompilationUnitDeclaration() {
 	if (this.scope != null) {
 		return this.scope.compilationUnitScope().referenceContext;
@@ -592,6 +596,7 @@ public void generateCode(ClassFile enclosingClassFile) {
 /**
  * Bytecode generation for a local inner type (API as a normal statement code gen)
  */
+@Override
 public void generateCode(BlockScope blockScope, CodeStream codeStream) {
 	if ((this.bits & ASTNode.IsReachable) == 0) {
 		return;
@@ -637,6 +642,7 @@ public void generateCode(CompilationUnitScope unitScope) {
 	generateCode((ClassFile) null);
 }
 
+@Override
 public boolean hasErrors() {
 	return this.ignoreFurtherInvestigation;
 }
@@ -908,6 +914,7 @@ public void parseMethods(Parser parser, CompilationUnitDeclaration unit) {
 	}
 }
 
+@Override
 public StringBuffer print(int indent, StringBuffer output) {
 	if (this.javadoc != null) {
 		this.javadoc.print(indent, output);
@@ -1002,6 +1009,7 @@ public StringBuffer printHeader(int indent, StringBuffer output) {
 	return output;
 }
 
+@Override
 public StringBuffer printStatement(int tab, StringBuffer output) {
 	return print(tab, output);
 }
@@ -1021,6 +1029,13 @@ public void resolve() {
 		return;
 	}
 	try {
+		if (CharOperation.equals(this.name, TypeConstants.VAR)) {
+			if (this.scope.compilerOptions().sourceLevel < ClassFileConstants.JDK10) {
+				this.scope.problemReporter().varIsReservedTypeNameInFuture(this);
+			} else {
+				this.scope.problemReporter().varIsReservedTypeName(this);
+			}
+		}
 		// resolve annotations and check @Deprecated annotation
 		long annotationTagBits = sourceType.getAnnotationTagBits();
 		if ((annotationTagBits & TagBits.AnnotationDeprecated) == 0
@@ -1239,6 +1254,7 @@ public void resolve() {
 /**
  * Resolve a local type declaration
  */
+@Override
 public void resolve(BlockScope blockScope) {
 
 	// need to build its scope first and proceed with binding's creation
@@ -1325,10 +1341,12 @@ public void resolve(CompilationUnitScope upperScope) {
 	updateMaxFieldCount();
 }
 
+@Override
 public void tagAsHavingErrors() {
 	this.ignoreFurtherInvestigation = true;
 }
 
+@Override
 public void tagAsHavingIgnoredMandatoryErrors(int problemId) {
 	// Nothing to do for this context;
 }
@@ -1392,6 +1410,7 @@ public void traverse(ASTVisitor visitor, CompilationUnitScope unitScope) {
 /**
  *	Iteration for a local inner type
  */
+@Override
 public void traverse(ASTVisitor visitor, BlockScope blockScope) {
 	try {
 		if (visitor.visit(this, blockScope)) {
