@@ -453,6 +453,7 @@ public class ClassScope extends Scope {
 		sourceType.modifiers |= ExtraCompilerModifiers.AccGenericSignature;
 	}
 
+	@Override
 	void resolveTypeParameter(TypeParameter typeParameter) {
 		typeParameter.resolve(this);
 	}
@@ -465,7 +466,7 @@ public class ClassScope extends Scope {
 		ReferenceBinding enclosingType = sourceType.enclosingType();
 		boolean isMemberType = sourceType.isMemberType();
 		if (isMemberType) {
-			if (!sourceType.isStatic())
+			if (sourceType.hasEnclosingInstanceContext())
 				modifiers |= (enclosingType.modifiers & ExtraCompilerModifiers.AccGenericSignature);
 			modifiers |= (enclosingType.modifiers & ClassFileConstants.AccStrictfp);
 			// checks for member types before local types to catch local members
@@ -1349,6 +1350,7 @@ public class ClassScope extends Scope {
 	* (unit, type or method) in case the problem handler decides it is necessary
 	* to abort.
 	*/
+	@Override
 	public ProblemReporter problemReporter() {
 		MethodScope outerMethodScope;
 		if ((outerMethodScope = outerMostMethodScope()) == null) {
@@ -1398,6 +1400,7 @@ public class ClassScope extends Scope {
 		return this.parent.checkRedundantDefaultNullness(nullBits, sourceStart);
 	}
 	
+	@Override
 	public String toString() {
 		if (this.referenceContext != null)
 			return "--- Class Scope ---\n\n"  //$NON-NLS-1$
