@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2004, 2017 IBM Corporation and others.
+ * Copyright (c) 2004, 2018 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -229,6 +229,7 @@ public class ASTParser {
 			case AST.JLS4_INTERNAL:
 			case AST.JLS8_INTERNAL:
 			case AST.JLS9_INTERNAL:
+			case AST.JLS10_INTERNAL:
 				break;
 			default:
 				throw new IllegalArgumentException();
@@ -1161,7 +1162,7 @@ public class ASTParser {
 								// assumed to be "module-info.class" (which has no type):
 								fileNameString = this.typeRoot.getElementName();
 							}
-							sourceUnit = new BasicCompilationUnit(sourceString.toCharArray(), Util.toCharArrays(packageFragment.names), fileNameString, this.project);
+							sourceUnit = new BasicCompilationUnit(sourceString.toCharArray(), Util.toCharArrays(packageFragment.names), fileNameString, this.typeRoot);
 						} catch(JavaModelException e) {
 							// an error occured accessing the java element
 							StringWriter stringWriter = new StringWriter();
