@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2018 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -186,9 +186,7 @@ class DefaultBindingResolver extends BindingResolver {
 		this.fromJavaProject = fromJavaProject;
 	}
 
-	/*
-	 * Method declared on BindingResolver.
-	 */
+	@Override
 	synchronized ASTNode findDeclaringNode(IBinding binding) {
 		if (binding == null) {
 			return null;
@@ -206,6 +204,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return (ASTNode) this.bindingsToAstNodes.get(binding);
 	}
 
+	@Override
 	synchronized ASTNode findDeclaringNode(String bindingKey) {
 		if (bindingKey == null) {
 			return null;
@@ -242,6 +241,7 @@ class DefaultBindingResolver extends BindingResolver {
 
 	Util.BindingsToNodesMap getBindingsToNodesMap() {
 		return new Util.BindingsToNodesMap() {
+			@Override
 			public org.eclipse.jdt.internal.compiler.ast.ASTNode get(Binding binding) {
 				return (org.eclipse.jdt.internal.compiler.ast.ASTNode)
 					DefaultBindingResolver.this.newAstToOldAst.get(DefaultBindingResolver.this.bindingsToAstNodes.get(binding));
@@ -249,13 +249,12 @@ class DefaultBindingResolver extends BindingResolver {
 		};
 	}
 
+	@Override
 	synchronized org.eclipse.jdt.internal.compiler.ast.ASTNode getCorrespondingNode(ASTNode currentNode) {
 		return (org.eclipse.jdt.internal.compiler.ast.ASTNode) this.newAstToOldAst.get(currentNode);
 	}
 
-	/*
-	 * Method declared on BindingResolver.
-	 */
+	@Override
 	synchronized IMethodBinding getMethodBinding(org.eclipse.jdt.internal.compiler.lookup.MethodBinding methodBinding) {
 		return getMethodOrLambdaBinding(methodBinding, null, null);
 	}
@@ -289,6 +288,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
+	@Override
 	synchronized IMemberValuePairBinding getMemberValuePairBinding(ElementValuePair valuePair) {
 		if (valuePair == null || valuePair.binding == null) return null;
 		IMemberValuePairBinding binding =
@@ -303,6 +303,7 @@ class DefaultBindingResolver extends BindingResolver {
 	/**
 	 * @see org.eclipse.jdt.core.dom.BindingResolver#getModuleBinding(org.eclipse.jdt.internal.compiler.lookup.ModuleBinding)
 	 */
+	@Override
 	synchronized IModuleBinding getModuleBinding(org.eclipse.jdt.internal.compiler.lookup.ModuleBinding moduleBinding) {
 		if (moduleBinding != null) {
 			IModuleBinding binding = (IModuleBinding) this.bindingTables.compilerBindingsToASTBindings.get(moduleBinding);
@@ -314,9 +315,8 @@ class DefaultBindingResolver extends BindingResolver {
 		}
 		return null;
 	}
-	/*
-	 * Method declared on BindingResolver.
-	 */
+
+	@Override
 	synchronized IPackageBinding getPackageBinding(org.eclipse.jdt.internal.compiler.lookup.PackageBinding packageBinding) {
 		if (packageBinding == null || packageBinding instanceof ProblemPackageBinding) {
 			return null;
@@ -325,7 +325,8 @@ class DefaultBindingResolver extends BindingResolver {
 		if (binding != null) {
 			return binding;
 		}
-		binding = new PackageBinding(packageBinding, this);
+		binding = packageBinding instanceof ProblemPackageBinding ? new RecoveredPackageBinding(packageBinding, this) :
+				new PackageBinding(packageBinding, this);
 		this.bindingTables.compilerBindingsToASTBindings.put(packageBinding, binding);
 		return binding;
 	}
@@ -343,17 +344,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return value;
 	}
 
-	/**
-	 * Returns the new type binding corresponding to the given variable declaration.
-	 * This is used for recovered binding only.
-	 * <p>
-	 * The default implementation of this method returns <code>null</code>.
-	 * Subclasses may reimplement.
-	 * </p>
-	 *
-	 * @param variableDeclaration the given variable declaration
-	 * @return the new type binding
-	 */
+	@Override
 	synchronized ITypeBinding getTypeBinding(VariableDeclaration variableDeclaration) {
 		ITypeBinding binding = (ITypeBinding) this.bindingTables.compilerBindingsToASTBindings.get(variableDeclaration);
 		if (binding != null) {
@@ -364,17 +355,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return binding;
 	}
 
-	/**
-	 * Returns the new type binding corresponding to the given type.
-	 * This is used for recovered binding only.
-	 * <p>
-	 * The default implementation of this method returns <code>null</code>.
-	 * Subclasses may reimplement.
-	 * </p>
-	 *
-	 * @param type the given type
-	 * @return the new type binding
-	 */
+	@Override
 	synchronized ITypeBinding getTypeBinding(Type type) {
 		ITypeBinding binding = (ITypeBinding) this.bindingTables.compilerBindingsToASTBindings.get(type);
 		if (binding != null) {
@@ -385,9 +366,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return binding;
 	}
 
-	/*
-	 * Method declared on BindingResolver.
-	 */
+	@Override
 	synchronized ITypeBinding getTypeBinding(org.eclipse.jdt.internal.compiler.lookup.TypeBinding referenceBinding) {
 		return internalGetTypeBinding(referenceBinding, null);
 	}
@@ -443,9 +422,7 @@ class DefaultBindingResolver extends BindingResolver {
 		}
 	}
 
-	/*
-	 * Method declared on BindingResolver.
-	 */
+	@Override
 	synchronized ITypeBinding getTypeBinding(RecoveredTypeBinding recoveredTypeBinding, int dimensions) {
 		if (recoveredTypeBinding== null) {
 			return null;
@@ -499,13 +476,12 @@ class DefaultBindingResolver extends BindingResolver {
 		return this.getVariableBinding(variableBinding);
 	}
 
+	@Override
 	public WorkingCopyOwner getWorkingCopyOwner() {
 		return this.workingCopyOwner;
 	}
 
-	/*
-	 * Method declared on BindingResolver.
-	 */
+	@Override
 	synchronized IVariableBinding getVariableBinding(org.eclipse.jdt.internal.compiler.lookup.VariableBinding variableBinding) {
 		if (variableBinding != null) {
 			if (variableBinding.isValidBinding()) {
@@ -566,6 +542,7 @@ class DefaultBindingResolver extends BindingResolver {
 		}
 	}
 
+	@Override
 	synchronized IAnnotationBinding getAnnotationInstance(org.eclipse.jdt.internal.compiler.lookup.AnnotationBinding internalInstance) {
 		if (internalInstance == null) return null;
 		ReferenceBinding annotationType = internalInstance.getAnnotationType();
@@ -580,6 +557,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return domInstance != null ? domInstance : newDomInstance;
 	}
 
+	@Override
 	boolean isResolvedTypeInferredFromExpectedType(MethodInvocation methodInvocation) {
 		Object oldNode = this.newAstToOldAst.get(methodInvocation);
 		if (oldNode instanceof MessageSend) {
@@ -593,6 +571,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return false;
 	}
 
+	@Override
 	boolean isResolvedTypeInferredFromExpectedType(SuperMethodInvocation superMethodInvocation) {
 		Object oldNode = this.newAstToOldAst.get(superMethodInvocation);
 		if (oldNode instanceof MessageSend) {
@@ -606,6 +585,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return false;
 	}
 
+	@Override
 	boolean isResolvedTypeInferredFromExpectedType(ClassInstanceCreation classInstanceCreation) {
 		Object oldNode = this.newAstToOldAst.get(classInstanceCreation);
 		if (oldNode instanceof AllocationExpression) {
@@ -615,9 +595,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return false;
 	}
 
-	/*
-	 * Method declared on BindingResolver.
-	 */
+	@Override
 	LookupEnvironment lookupEnvironment() {
 		return this.scope.environment();
 	}
@@ -625,13 +603,12 @@ class DefaultBindingResolver extends BindingResolver {
 	/**
 	 * @see org.eclipse.jdt.core.dom.BindingResolver#recordScope(ASTNode, BlockScope)
 	 */
+	@Override
 	synchronized void recordScope(ASTNode astNode, BlockScope blockScope) {
 		this.astNodesToBlockScope.put(astNode, blockScope);
 	}
 
-	/*
-	 * @see BindingResolver#resolveBoxing(Expression)
-	 */
+	@Override
 	boolean resolveBoxing(Expression expression) {
 		org.eclipse.jdt.internal.compiler.ast.ASTNode node = (org.eclipse.jdt.internal.compiler.ast.ASTNode) this.newAstToOldAst.get(expression);
 		if (node instanceof org.eclipse.jdt.internal.compiler.ast.Expression) {
@@ -641,9 +618,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return false;
 	}
 
-	/*
-	 * @see BindingResolver#resolveUnboxing(Expression)
-	 */
+	@Override
 	boolean resolveUnboxing(Expression expression) {
 		org.eclipse.jdt.internal.compiler.ast.ASTNode node = (org.eclipse.jdt.internal.compiler.ast.ASTNode) this.newAstToOldAst.get(expression);
 		if (node instanceof org.eclipse.jdt.internal.compiler.ast.Expression) {
@@ -653,9 +628,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return false;
 	}
 
-	/*
-	 * @see BindingResolver#resolveConstantExpressionValue(Expression)
-	 */
+	@Override
 	Object resolveConstantExpressionValue(Expression expression) {
 		org.eclipse.jdt.internal.compiler.ast.ASTNode node = (org.eclipse.jdt.internal.compiler.ast.ASTNode) this.newAstToOldAst.get(expression);
 		if (node instanceof org.eclipse.jdt.internal.compiler.ast.Expression) {
@@ -679,9 +652,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
-	/*
-	 * @see BindingResolver#resolveConstructor(ClassInstanceCreation)
-	 */
+	@Override
 	synchronized IMethodBinding resolveConstructor(ClassInstanceCreation expression) {
 		org.eclipse.jdt.internal.compiler.ast.ASTNode node = (org.eclipse.jdt.internal.compiler.ast.ASTNode) this.newAstToOldAst.get(expression);
 		if (node != null && (node.bits & org.eclipse.jdt.internal.compiler.ast.ASTNode.IsAnonymousType) != 0) {
@@ -693,9 +664,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
-	/*
-	 * @see BindingResolver#resolveConstructor(ConstructorInvocation)
-	 */
+	@Override
 	synchronized IMethodBinding resolveConstructor(ConstructorInvocation expression) {
 		org.eclipse.jdt.internal.compiler.ast.ASTNode node = (org.eclipse.jdt.internal.compiler.ast.ASTNode) this.newAstToOldAst.get(expression);
 		if (node instanceof ExplicitConstructorCall) {
@@ -705,9 +674,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.jdt.core.dom.BindingResolver#resolveConstructor(org.eclipse.jdt.core.dom.EnumConstantDeclaration)
-	 */
+	@Override
 	IMethodBinding resolveConstructor(EnumConstantDeclaration enumConstantDeclaration) {
 		org.eclipse.jdt.internal.compiler.ast.ASTNode node = (org.eclipse.jdt.internal.compiler.ast.ASTNode) this.newAstToOldAst.get(enumConstantDeclaration);
 		if (node instanceof org.eclipse.jdt.internal.compiler.ast.FieldDeclaration) {
@@ -720,9 +687,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
-	/*
-	 * @see BindingResolver#resolveConstructor(SuperConstructorInvocation)
-	 */
+	@Override
 	synchronized IMethodBinding resolveConstructor(SuperConstructorInvocation expression) {
 		org.eclipse.jdt.internal.compiler.ast.ASTNode node = (org.eclipse.jdt.internal.compiler.ast.ASTNode) this.newAstToOldAst.get(expression);
 		if (node instanceof ExplicitConstructorCall) {
@@ -731,9 +696,8 @@ class DefaultBindingResolver extends BindingResolver {
 		}
 		return null;
 	}
-	/*
-	 * Method declared on BindingResolver.
-	 */
+
+	@Override
 	synchronized ITypeBinding resolveExpressionType(Expression expression) {
 		try {
 			switch(expression.getNodeType()) {
@@ -821,9 +785,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
-	/*
-	 * @see BindingResolver#resolveField(FieldAccess)
-	 */
+	@Override
 	synchronized IVariableBinding resolveField(FieldAccess fieldAccess) {
 		Object oldNode = this.newAstToOldAst.get(fieldAccess);
 		if (oldNode instanceof FieldReference) {
@@ -833,9 +795,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
-	/*
-	 * @see BindingResolver#resolveField(SuperFieldAccess)
-	 */
+	@Override
 	synchronized IVariableBinding resolveField(SuperFieldAccess fieldAccess) {
 		Object oldNode = this.newAstToOldAst.get(fieldAccess);
 		if (oldNode instanceof FieldReference) {
@@ -845,9 +805,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
-	/*
-	 * @see BindingResolver#resolveImport(ImportDeclaration)
-	 */
+	@Override
 	synchronized IBinding resolveImport(ImportDeclaration importDeclaration) {
 		if (this.scope == null) return null;
 		try {
@@ -911,9 +869,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.jdt.core.dom.BindingResolver#resolveMember(org.eclipse.jdt.core.dom.AnnotationTypeMemberDeclaration)
-	 */
+	@Override
 	IMethodBinding resolveMember(AnnotationTypeMemberDeclaration declaration) {
 		Object oldNode = this.newAstToOldAst.get(declaration);
 		if (oldNode instanceof AbstractMethodDeclaration) {
@@ -932,9 +888,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
-	/*
-	 * Method declared on BindingResolver.
-	 */
+	@Override
 	synchronized IMethodBinding resolveMethod(LambdaExpression lambda) {
 		Object oldNode = this.newAstToOldAst.get(lambda);
 		if (oldNode instanceof org.eclipse.jdt.internal.compiler.ast.LambdaExpression) {
@@ -999,9 +953,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
-	/*
-	 * Method declared on BindingResolver.
-	 */
+	@Override
 	synchronized IMethodBinding resolveMethod(MethodDeclaration method) {
 		Object oldNode = this.newAstToOldAst.get(method);
 		if (oldNode instanceof AbstractMethodDeclaration) {
@@ -1019,9 +971,8 @@ class DefaultBindingResolver extends BindingResolver {
 		}
 		return null;
 	}
-/*
-	 * Method declared on BindingResolver.
-	 */
+
+	@Override
 	synchronized IMethodBinding resolveMethod(MethodInvocation method) {
 		Object oldNode = this.newAstToOldAst.get(method);
 		if (oldNode instanceof MessageSend) {
@@ -1030,9 +981,8 @@ class DefaultBindingResolver extends BindingResolver {
 		}
 		return null;
 	}
-	/*
-	 * Method declared on BindingResolver.
-	 */
+
+	@Override
 	synchronized IMethodBinding resolveMethod(MethodReference methodReference) {
 		Object oldNode = this.newAstToOldAst.get(methodReference);
 		if (oldNode instanceof org.eclipse.jdt.internal.compiler.ast.ReferenceExpression) {
@@ -1047,9 +997,8 @@ class DefaultBindingResolver extends BindingResolver {
 		}
 		return null;
 	}
-	/*
-	 * Method declared on BindingResolver.
-	 */
+
+	@Override
 	synchronized IMethodBinding resolveMethod(SuperMethodInvocation method) {
 		Object oldNode = this.newAstToOldAst.get(method);
 		if (oldNode instanceof MessageSend) {
@@ -1278,9 +1227,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
-	/*
-	 * Method declared on BindingResolver.
-	 */
+	@Override
 	synchronized IBinding resolveName(Name name) {
 		org.eclipse.jdt.internal.compiler.ast.ASTNode node = (org.eclipse.jdt.internal.compiler.ast.ASTNode) this.newAstToOldAst.get(name);
 		int index = name.index;
@@ -1507,7 +1454,9 @@ class DefaultBindingResolver extends BindingResolver {
 			QualifiedSuperReference qualifiedSuperReference = (QualifiedSuperReference) node;
 			return this.getTypeBinding(qualifiedSuperReference.qualification.resolvedType);
 		} else if (node instanceof LocalDeclaration) {
-			return this.getVariableBinding(((LocalDeclaration)node).binding);
+			return name.getAST().apiLevel() >= AST.JLS10_INTERNAL && name instanceof SimpleName && ((SimpleName) name).isVar()  ? 
+					resolveTypeBindingForName(name) :
+					this.getVariableBinding(((LocalDeclaration)node).binding);
 		} else if (node instanceof JavadocFieldReference) {
 			JavadocFieldReference fieldRef = (JavadocFieldReference) node;
 			if (fieldRef.methodBinding != null) {
@@ -1554,9 +1503,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
-	/*
-	 * @see BindingResolver#resolvePackage(PackageDeclaration)
-	 */
+	@Override
 	synchronized IPackageBinding resolvePackage(PackageDeclaration pkg) {
 		if (this.scope == null) return null;
 		try {
@@ -1592,10 +1539,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
-	/* (non-Javadoc)
-	 * @see BindingResolver#resolveReference(MemberRef)
-     * @since 3.0
-	 */
+	@Override
 	synchronized IBinding resolveReference(MemberRef ref) {
 		org.eclipse.jdt.internal.compiler.ast.Expression expression = (org.eclipse.jdt.internal.compiler.ast.Expression) this.newAstToOldAst.get(ref);
 		if (expression instanceof TypeReference) {
@@ -1610,10 +1554,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
-	/* (non-Javadoc)
-	 * @see BindingResolver#resolveMemberValuePair(MemberValuePair)
-     * @since 3.2
-	 */
+	@Override
 	synchronized IMemberValuePairBinding resolveMemberValuePair(org.eclipse.jdt.core.dom.MemberValuePair memberValuePair) {
 		MemberValuePair valuePair = (MemberValuePair) this.newAstToOldAst.get(memberValuePair);
 		if (valuePair != null) {
@@ -1646,10 +1587,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
-	/* (non-Javadoc)
-	 * @see BindingResolver#resolveReference(MethodRef)
-     * @since 3.0
-	 */
+	@Override
 	synchronized IBinding resolveReference(MethodRef ref) {
 		org.eclipse.jdt.internal.compiler.ast.Expression expression = (org.eclipse.jdt.internal.compiler.ast.Expression) this.newAstToOldAst.get(ref);
 		if (expression instanceof JavadocMessageSend) {
@@ -1661,9 +1599,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.jdt.core.dom.BindingResolver#resolveType(org.eclipse.jdt.core.dom.AnnotationTypeDeclaration)
-	 */
+	@Override
 	ITypeBinding resolveType(AnnotationTypeDeclaration type) {
 		final Object node = this.newAstToOldAst.get(type);
 		if (node instanceof org.eclipse.jdt.internal.compiler.ast.TypeDeclaration) {
@@ -1681,9 +1617,8 @@ class DefaultBindingResolver extends BindingResolver {
 		}
 		return null;
 	}
-	/*
-	 * @see BindingResolver#resolveType(AnonymousClassDeclaration)
-	 */
+
+	@Override
 	synchronized ITypeBinding resolveType(AnonymousClassDeclaration type) {
 		org.eclipse.jdt.internal.compiler.ast.ASTNode node = (org.eclipse.jdt.internal.compiler.ast.ASTNode) this.newAstToOldAst.get(type);
 		if (node != null && (node.bits & org.eclipse.jdt.internal.compiler.ast.ASTNode.IsAnonymousType) != 0) {
@@ -1703,9 +1638,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.jdt.core.dom.BindingResolver#resolveType(org.eclipse.jdt.core.dom.EnumDeclaration)
-	 */
+	@Override
 	ITypeBinding resolveType(EnumDeclaration type) {
 		final Object node = this.newAstToOldAst.get(type);
 		if (node instanceof org.eclipse.jdt.internal.compiler.ast.TypeDeclaration) {
@@ -1724,13 +1657,14 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
-	/*
-	 * Method declared on BindingResolver.
-	 */
+	@Override
 	synchronized ITypeBinding resolveType(Type type) {
 		// retrieve the old ast node
 		org.eclipse.jdt.internal.compiler.ast.ASTNode node = (org.eclipse.jdt.internal.compiler.ast.ASTNode) this.newAstToOldAst.get(type);
 		org.eclipse.jdt.internal.compiler.lookup.TypeBinding binding = null;
+		if (type.getAST().apiLevel() >= AST.JLS10_INTERNAL && type.isVar()) {
+			return resolveTypeBindingForName(((SimpleType) type).getName());
+		}
 		if (node != null) {
 			if (node instanceof Receiver) {
 				node = ((Receiver) node).type;
@@ -1843,9 +1777,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return newbies;
 	}
 
-	/*
-	 * Method declared on BindingResolver.
-	 */
+	@Override
 	synchronized ITypeBinding resolveType(TypeDeclaration type) {
 		final Object node = this.newAstToOldAst.get(type);
 		if (node instanceof org.eclipse.jdt.internal.compiler.ast.TypeDeclaration) {
@@ -1865,6 +1797,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
+	@Override
 	synchronized ITypeBinding resolveTypeParameter(TypeParameter typeParameter) {
 		final Object node = this.newAstToOldAst.get(typeParameter);
 		if (node instanceof org.eclipse.jdt.internal.compiler.ast.TypeParameter) {
@@ -1883,9 +1816,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.jdt.core.dom.BindingResolver#resolveVariable(org.eclipse.jdt.core.dom.EnumConstantDeclaration)
-	 */
+	@Override
 	synchronized IVariableBinding resolveVariable(EnumConstantDeclaration enumConstant) {
 		final Object node = this.newAstToOldAst.get(enumConstant);
 		if (node instanceof org.eclipse.jdt.internal.compiler.ast.FieldDeclaration) {
@@ -1903,9 +1834,8 @@ class DefaultBindingResolver extends BindingResolver {
 		}
 		return null;
 	}
-	/*
-	 * Method declared on BindingResolver.
-	 */
+
+	@Override
 	synchronized IVariableBinding resolveVariable(VariableDeclaration variable) {
 		final Object node = this.newAstToOldAst.get(variable);
 		if (node instanceof AbstractVariableDeclaration) {
@@ -1930,9 +1860,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
-	/*
-	 * Method declared on BindingResolver.
-	 */
+	@Override
 	synchronized ITypeBinding resolveWellKnownType(String name) {
 		if (this.scope == null) return null;
 		ITypeBinding typeBinding = null;
@@ -1997,6 +1925,7 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
+	@Override
 	synchronized IAnnotationBinding resolveAnnotation(final Annotation domASTNode) {
 		Object oldNode = this.newAstToOldAst.get(domASTNode);
 		if (oldNode instanceof org.eclipse.jdt.internal.compiler.ast.Annotation) {
@@ -2012,23 +1941,17 @@ class DefaultBindingResolver extends BindingResolver {
 		return null;
 	}
 
-	/*
-	 * Method declared on BindingResolver.
-	 */
+	@Override
 	public CompilationUnitScope scope() {
 		return this.scope;
 	}
 
-	/*
-	 * Method declared on BindingResolver.
-	 */
+	@Override
 	synchronized void store(ASTNode node, org.eclipse.jdt.internal.compiler.ast.ASTNode oldASTNode) {
 		this.newAstToOldAst.put(node, oldASTNode);
 	}
 
-	/*
-	 * Method declared on BindingResolver.
-	 */
+	@Override
 	synchronized void updateKey(ASTNode node, ASTNode newNode) {
 		Object astNode = this.newAstToOldAst.remove(node);
 		if (astNode != null) {
@@ -2036,25 +1959,7 @@ class DefaultBindingResolver extends BindingResolver {
 		}
 	}
 
-	/**
-	 * Answer an array type binding with the given type binding and the given
-	 * dimensions.
-	 *
-	 * <p>If the given type binding is an array binding, then the resulting dimensions is the given dimensions
-	 * plus the existing dimensions of the array binding. Otherwise the resulting dimensions is the given
-	 * dimensions.</p>
-	 *
-	 * <p>
-	 * The default implementation of this method returns <code>null</code>.
-	 * Subclasses may reimplement.
-	 * </p>
-	 *
-	 * @param typeBinding the given type binding
-	 * @param dimensions the given dimensions
-	 * @return an array type binding with the given type binding and the given
-	 * dimensions
-	 * @throws IllegalArgumentException if the type binding represents the <code>void</code> type binding
-	 */
+	@Override
 	ITypeBinding resolveArrayType(ITypeBinding typeBinding, int dimensions) {
 		if (typeBinding instanceof RecoveredTypeBinding) throw new IllegalArgumentException("Cannot be called on a recovered type binding"); //$NON-NLS-1$
 		ITypeBinding leafComponentType = typeBinding;
