@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2015 IBM Corporation and others.
+ * Copyright (c) 2000, 2017 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -90,6 +90,7 @@ class TypeBinding implements ITypeBinding {
 		this.prototype = (TypeBinding) (compilerPrototype == null || compilerPrototype == binding ? null : resolver.getTypeBinding(compilerPrototype)); //$IDENTITY-COMPARISON$
 	}
 
+	@Override
 	public ITypeBinding createArrayType(int dimension) {
 		int realDimensions = dimension;
 		realDimensions += getDimensions();
@@ -99,6 +100,7 @@ class TypeBinding implements ITypeBinding {
 		return this.resolver.resolveArrayType(this, dimension);
 	}
 
+	@Override
 	public IAnnotationBinding[] getAnnotations() {
 		if (this.prototype != null) {
 			return this.prototype.getAnnotations();
@@ -144,10 +146,7 @@ class TypeBinding implements ITypeBinding {
 		return AnnotationBinding.NoAnnotations;
 	}
 
-	/*
-	 * @see ITypeBinding#getBinaryName()
-	 * @since 3.0
-	 */
+	@Override
 	public String getBinaryName() {
 		if (this.binding.isCapture()) {
 			return null; // no binary name for capture binding
@@ -184,9 +183,7 @@ class TypeBinding implements ITypeBinding {
 		return new String(dotSeparated);
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.jdt.core.dom.ITypeBinding#getBound()
-	 */
+	@Override
 	public ITypeBinding getBound() {
 		switch (this.binding.kind()) {
 			case Binding.WILDCARD_TYPE :
@@ -200,9 +197,7 @@ class TypeBinding implements ITypeBinding {
 		return null;
 	}
 	
-	/* (non-Javadoc)
-	 * @see org.eclipse.jdt.core.dom.ITypeBinding#getGenericTypeOfWildcardType()
-	 */
+	@Override
 	public ITypeBinding getGenericTypeOfWildcardType() {
 		switch (this.binding.kind()) {
 			case Binding.WILDCARD_TYPE :
@@ -215,9 +210,7 @@ class TypeBinding implements ITypeBinding {
 		return null;
 	}
 	
-	/* (non-Javadoc)
-	 * @see org.eclipse.jdt.core.dom.ITypeBinding#getRank()
-	 */
+	@Override
 	public int getRank() {
 		switch (this.binding.kind()) {
 			case Binding.WILDCARD_TYPE :
@@ -229,9 +222,7 @@ class TypeBinding implements ITypeBinding {
 		}
 	}
 	
-	/*
-	 * @see ITypeBinding#getComponentType()
-	 */
+	@Override
 	public ITypeBinding getComponentType() {
 		if (!isArray()) {
 			return null;
@@ -240,9 +231,7 @@ class TypeBinding implements ITypeBinding {
 		return this.resolver.getTypeBinding(arrayBinding.elementsType());
 	}
 
-	/*
-	 * @see ITypeBinding#getDeclaredFields()
-	 */
+	@Override
 	public synchronized IVariableBinding[] getDeclaredFields() {
 		if (this.prototype != null) {
 			return this.prototype.getDeclaredFields();
@@ -286,9 +275,7 @@ class TypeBinding implements ITypeBinding {
 		return this.fields = NO_VARIABLE_BINDINGS;
 	}
 
-	/*
-	 * @see ITypeBinding#getDeclaredMethods()
-	 */
+	@Override
 	public synchronized IMethodBinding[] getDeclaredMethods() {
 		if (this.prototype != null) {
 			return this.prototype.getDeclaredMethods();
@@ -338,13 +325,12 @@ class TypeBinding implements ITypeBinding {
 	 * @see ITypeBinding#getDeclaredModifiers()
 	 * @deprecated Use ITypeBinding#getModifiers() instead
 	 */
+	@Override
 	public int getDeclaredModifiers() {
 		return getModifiers();
 	}
 
-	/*
-	 * @see ITypeBinding#getDeclaredTypes()
-	 */
+	@Override
 	public synchronized ITypeBinding[] getDeclaredTypes() { // should not deflect to prototype.
 		if (this.members != null) {
 			return this.members;
@@ -377,9 +363,7 @@ class TypeBinding implements ITypeBinding {
 		return this.members = NO_TYPE_BINDINGS;
 	}
 
-	/*
-	 * @see ITypeBinding#getDeclaringMethod()
-	 */
+	@Override
 	public synchronized IMethodBinding getDeclaringMethod() {
 		if (this.binding instanceof org.eclipse.jdt.internal.compiler.lookup.LocalTypeBinding) {
 			org.eclipse.jdt.internal.compiler.lookup.LocalTypeBinding localTypeBinding = (org.eclipse.jdt.internal.compiler.lookup.LocalTypeBinding) this.binding;
@@ -415,9 +399,7 @@ class TypeBinding implements ITypeBinding {
 		return null;
 	}
 
-	/*
-	 * @see ITypeBinding#getDeclaringClass()
-	 */
+	@Override
 	public synchronized ITypeBinding getDeclaringClass() {
 		if (isClass() || isInterface() || isEnum()) {
 			ReferenceBinding referenceBinding = (ReferenceBinding) this.binding;
@@ -451,15 +433,20 @@ class TypeBinding implements ITypeBinding {
 		}
 		return null;
 	}
-
+	@Override
+	public IModuleBinding getModule() {
+		if (this.binding instanceof ReferenceBinding && !this.binding.isTypeVariable()) {
+			IPackageBinding packageBinding = this.resolver.getPackageBinding(((ReferenceBinding) this.binding).getPackage());
+			return packageBinding != null ? packageBinding.getModule() : null;
+		}
+		return null;
+	}
 	@Override
 	public IBinding getDeclaringMember() {
 		return null;
 	}
 
-	/*
-	 * @see ITypeBinding#getDimensions()
-	 */
+	@Override
 	public int getDimensions() {
 		if (!isArray()) {
 			return 0;
@@ -468,9 +455,7 @@ class TypeBinding implements ITypeBinding {
 		return arrayBinding.dimensions;
 	}
 
-	/*
-	 * @see ITypeBinding#getElementType()
-	 */
+	@Override
 	public ITypeBinding getElementType() {
 		if (!isArray()) {
 			return null;
@@ -479,25 +464,18 @@ class TypeBinding implements ITypeBinding {
 		return this.resolver.getTypeBinding(arrayBinding.leafComponentType);
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.jdt.core.dom.ITypeBinding#getTypeDeclaration()
-	 */
+	@Override
 	public ITypeBinding getTypeDeclaration() {
 		if (this.binding instanceof ParameterizedTypeBinding)
 			return this.resolver.getTypeBinding(((ParameterizedTypeBinding)this.binding).genericType());
 		return this.resolver.getTypeBinding(this.binding.unannotated());
 	}
 	
-	/* (non-Javadoc)
-	 * @see org.eclipse.jdt.core.dom.ITypeBinding#getErasure()
-	 */
+	@Override
 	public ITypeBinding getErasure() {
 		return this.resolver.getTypeBinding(this.binding.erasure());
 	}
 	
-	/* (non-Javadoc)
-	 * @see org.eclipse.jdt.core.dom.ITypeBinding#getFunctionalInterfaceMethod
-	 */
 	@Override
 	public IMethodBinding getFunctionalInterfaceMethod() {
 		Scope scope = this.resolver.scope();
@@ -509,6 +487,7 @@ class TypeBinding implements ITypeBinding {
 		return this.resolver.getMethodBinding(sam);
 	}
 
+	@Override
 	public synchronized ITypeBinding[] getInterfaces() {
 		if (this.prototype != null) {
 			return this.prototype.getInterfaces();
@@ -567,6 +546,7 @@ class TypeBinding implements ITypeBinding {
 		return intersectionBindings;
 	}
 
+	@Override
 	public IJavaElement getJavaElement() {
 		JavaElement element = getUnresolvedJavaElement();
 		if (element != null)
@@ -603,9 +583,7 @@ class TypeBinding implements ITypeBinding {
 		return null;
 	}
 
-	/*
-	 * @see IBinding#getKey()
-	 */
+	@Override
 	public String getKey() {
 		if (this.key == null) {
 			this.key = new String(this.binding.computeUniqueKey());
@@ -613,16 +591,12 @@ class TypeBinding implements ITypeBinding {
 		return this.key;
 	}
 
-	/*
-	 * @see IBinding#getKind()
-	 */
+	@Override
 	public int getKind() {
 		return IBinding.TYPE;
 	}
 
-	/*
-	 * @see IBinding#getModifiers()
-	 */
+	@Override
 	public int getModifiers() {
 		if (isClass()) {
 			ReferenceBinding referenceBinding = (ReferenceBinding) this.binding;
@@ -651,6 +625,7 @@ class TypeBinding implements ITypeBinding {
 		}
 	}
 
+	@Override
 	public String getName() {
 		StringBuffer buffer;
 		switch (this.binding.kind()) {
@@ -731,9 +706,7 @@ class TypeBinding implements ITypeBinding {
 		}
 	}
 
-	/*
-	 * @see ITypeBinding#getPackage()
-	 */
+	@Override
 	public IPackageBinding getPackage() {
 		switch (this.binding.kind()) {
 			case Binding.BASE_TYPE :
@@ -751,6 +724,7 @@ class TypeBinding implements ITypeBinding {
 	/**
 	 * @see org.eclipse.jdt.core.dom.ITypeBinding#getQualifiedName()
 	 */
+	@Override
 	public String getQualifiedName() {
 		StringBuffer buffer;
 		switch (this.binding.kind()) {
@@ -863,9 +837,7 @@ class TypeBinding implements ITypeBinding {
 		}
 	}
 
-	/*
-	 * @see ITypeBinding#getSuperclass()
-	 */
+	@Override
 	public synchronized ITypeBinding getSuperclass() {
 		if (this.binding == null)
 			return null;
@@ -896,9 +868,7 @@ class TypeBinding implements ITypeBinding {
 		return this.resolver.getTypeBinding(superclass);
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.jdt.core.dom.ITypeBinding#getTypeArguments()
-	 */
+	@Override
 	public ITypeBinding[] getTypeArguments() {
 		if (this.prototype != null) {
 			return this.prototype.getTypeArguments();
@@ -923,9 +893,7 @@ class TypeBinding implements ITypeBinding {
 		return this.typeArguments = NO_TYPE_BINDINGS;
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.jdt.core.dom.ITypeBinding#getTypeBounds()
-	 */
+	@Override
 	public ITypeBinding[] getTypeBounds() {
 		if (this.prototype != null) {
 			return this.prototype.getTypeBounds();
@@ -991,9 +959,7 @@ class TypeBinding implements ITypeBinding {
 		return this.bounds = NO_TYPE_BINDINGS;
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.jdt.core.dom.ITypeBinding#getTypeParameters()
-	 */
+	@Override
 	public ITypeBinding[] getTypeParameters() {
 		if (this.prototype != null) {
 			return this.prototype.getTypeParameters();
@@ -1022,10 +988,7 @@ class TypeBinding implements ITypeBinding {
 		return this.typeParameters = NO_TYPE_BINDINGS;
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.jdt.core.dom.ITypeBinding#getWildcard()
-	 * @since 3.1
-	 */
+	@Override
 	public ITypeBinding getWildcard() {
 		if (this.binding instanceof CaptureBinding) {
 			CaptureBinding captureBinding = (CaptureBinding) this.binding;
@@ -1034,10 +997,7 @@ class TypeBinding implements ITypeBinding {
 		return null;
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.jdt.core.dom.ITypeBinding#isGenericType()
-	 * @since 3.1
-	 */
+	@Override
 	public boolean isGenericType() {
 		// equivalent to return getTypeParameters().length > 0;
 		if (isRawType()) {
@@ -1047,16 +1007,12 @@ class TypeBinding implements ITypeBinding {
 		return (typeVariableBindings != null && typeVariableBindings.length > 0);
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.jdt.core.dom.ITypeBinding#isAnnotation()
-	 */
+	@Override
 	public boolean isAnnotation() {
 		return this.binding.isAnnotationType();
 	}
 
-	/*
-	 * @see ITypeBinding#isAnonymous()
-	 */
+	@Override
 	public boolean isAnonymous() {
 		if (isClass() || isInterface() || isEnum()) {
 			ReferenceBinding referenceBinding = (ReferenceBinding) this.binding;
@@ -1065,16 +1021,12 @@ class TypeBinding implements ITypeBinding {
 		return false;
 	}
 
-	/*
-	 * @see ITypeBinding#isArray()
-	 */
+	@Override
 	public boolean isArray() {
 		return this.binding.isArrayType();
 	}
 
-	/* (non-Javadoc)
-	 * @see ITypeBinding#isAssignmentCompatible(ITypeBinding)
-	 */
+	@Override
 	public boolean isAssignmentCompatible(ITypeBinding type) {
 		try {
 			if (this == type) return true; //$IDENTITY-COMPARISON$
@@ -1090,16 +1042,12 @@ class TypeBinding implements ITypeBinding {
 		}
 	}
 
-	/* (non-Javadoc)
-	 * @see ITypeBinding#isCapture()
-	 */
+	@Override
 	public boolean isCapture() {
 		return this.binding.isCapture();
 	}
 
-	/* (non-Javadoc)
-	 * @see ITypeBinding#isCastCompatible(ITypeBinding)
-	 */
+	@Override
 	public boolean isCastCompatible(ITypeBinding type) {
 		try {
 			Scope scope = this.resolver.scope();
@@ -1116,9 +1064,7 @@ class TypeBinding implements ITypeBinding {
 		}
 	}
 
-	/*
-	 * @see ITypeBinding#isClass()
-	 */
+	@Override
 	public boolean isClass() {
 		switch (this.binding.kind()) {
 			case Binding.TYPE_PARAMETER :
@@ -1129,9 +1075,7 @@ class TypeBinding implements ITypeBinding {
 		return this.binding.isClass();
 	}
 
-	/*
-	 * @see IBinding#isDeprecated()
-	 */
+	@Override
 	public boolean isDeprecated() {
 		if (isClass() || isInterface() || isEnum()) {
 			ReferenceBinding referenceBinding = (ReferenceBinding) this.binding;
@@ -1140,17 +1084,12 @@ class TypeBinding implements ITypeBinding {
 		return false;
 	}
 
-	/* (non-Javadoc)
-	 * @see ITypeBinding#isEnum()
-	 */
+	@Override
 	public boolean isEnum() {
 		return this.binding.isEnum();
 	}
 
-	/*
-	 * @see IBinding#isEqualTo(Binding)
-	 * @since 3.1
-	 */
+	@Override
 	public boolean isEqualTo(IBinding other) {
 		if (other == this) {
 			// identical binding - equal (key or no key)
@@ -1171,9 +1110,7 @@ class TypeBinding implements ITypeBinding {
 		return BindingComparator.isEqual(this.binding, otherBinding);
 	}
 
-	/*
-	 * @see ITypeBinding#isFromSource()
-	 */
+	@Override
 	public boolean isFromSource() {
 		if (isClass() || isInterface() || isEnum()) {
 			ReferenceBinding referenceBinding = (ReferenceBinding) this.binding;
@@ -1215,9 +1152,7 @@ class TypeBinding implements ITypeBinding {
 		return false;
 	}
 
-	/*
-	 * @see ITypeBinding#isInterface()
-	 */
+	@Override
 	public boolean isInterface() {
 		switch (this.binding.kind()) {
 			case Binding.TYPE_PARAMETER :
@@ -1228,17 +1163,13 @@ class TypeBinding implements ITypeBinding {
 		return this.binding.isInterface();
 	}
 
-	/*
-	 * @see ITypeBinding#isIntersectionType18
-	 */
+	@Override
 	public boolean isIntersectionType() {
 		int kind = this.binding.kind();
 		return kind == Binding.INTERSECTION_TYPE18 || kind == Binding.INTERSECTION_TYPE;
 	}
 
-	/*
-	 * @see ITypeBinding#isLocal()
-	 */
+	@Override
 	public boolean isLocal() {
 		if (isClass() || isInterface() || isEnum()) {
 			ReferenceBinding referenceBinding = (ReferenceBinding) this.binding;
@@ -1247,9 +1178,7 @@ class TypeBinding implements ITypeBinding {
 		return false;
 	}
 
-	/*
-	 * @see ITypeBinding#isMember()
-	 */
+	@Override
 	public boolean isMember() {
 		if (isClass() || isInterface() || isEnum()) {
 			ReferenceBinding referenceBinding = (ReferenceBinding) this.binding;
@@ -1258,9 +1187,7 @@ class TypeBinding implements ITypeBinding {
 		return false;
 	}
 
-	/*
-	 * @see ITypeBinding#isNested()
-	 */
+	@Override
 	public boolean isNested() {
 		if (isClass() || isInterface() || isEnum()) {
 			ReferenceBinding referenceBinding = (ReferenceBinding) this.binding;
@@ -1272,41 +1199,32 @@ class TypeBinding implements ITypeBinding {
 	/**
 	 * @see ITypeBinding#isNullType()
 	 */
+	@Override
 	public boolean isNullType() {
 		return this.binding == org.eclipse.jdt.internal.compiler.lookup.TypeBinding.NULL;
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.jdt.core.dom.ITypeBinding#isParameterizedType()
-	 */
+	@Override
 	public boolean isParameterizedType() {
 		return this.binding.isParameterizedTypeWithActualArguments();
 	}
 
-	/*
-	 * @see ITypeBinding#isPrimitive()
-	 */
+	@Override
 	public boolean isPrimitive() {
 		return !isNullType() && this.binding.isBaseType();
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.jdt.core.dom.ITypeBinding#isRawType()
-	 */
+	@Override
 	public boolean isRawType() {
 		return this.binding.isRawType();
 	}
 
-	/* (non-Javadoc)
-	 * @see IBinding#isRecovered()
-	 */
+	@Override
 	public boolean isRecovered() {
 		return (this.binding.tagBits & TagBits.HasMissingType) != 0;
 	}
 
-	/* (non-Javadoc)
-	 * @see ITypeBinding#isSubTypeCompatible(ITypeBinding)
-	 */
+	@Override
 	public boolean isSubTypeCompatible(ITypeBinding type) {
 		try {
 			if (this == type) return true; //$IDENTITY-COMPARISON$
@@ -1325,13 +1243,12 @@ class TypeBinding implements ITypeBinding {
 	/**
 	 * @see IBinding#isSynthetic()
 	 */
+	@Override
 	public boolean isSynthetic() {
 		return false;
 	}
 
-	/*
-	 * @see ITypeBinding#isTopLevel()
-	 */
+	@Override
 	public boolean isTopLevel() {
 		if (isClass() || isInterface() || isEnum()) {
 			ReferenceBinding referenceBinding = (ReferenceBinding) this.binding;
@@ -1340,16 +1257,12 @@ class TypeBinding implements ITypeBinding {
 		return false;
 	}
 
-	/*
-	 * @see ITypeBinding#isTypeVariable()
-	 */
+	@Override
 	public boolean isTypeVariable() {
 		return this.binding.isTypeVariable() && !this.binding.isCapture();
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.jdt.core.dom.ITypeBinding#isUpperbound()
-	 */
+	@Override
 	public boolean isUpperbound() {
 		switch (this.binding.kind()) {
 			case Binding.WILDCARD_TYPE :
@@ -1360,9 +1273,7 @@ class TypeBinding implements ITypeBinding {
 		return false;
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.jdt.core.dom.ITypeBinding#isWildcardType()
-	 */
+	@Override
 	public boolean isWildcardType() {
 		return this.binding.isWildcard();
 	}
@@ -1371,13 +1282,12 @@ class TypeBinding implements ITypeBinding {
 	 * For debugging purpose only.
 	 * @see java.lang.Object#toString()
 	 */
+	@Override
 	public String toString() {
 		return this.binding.toString();
 	}
 
-	/*
-	 * @see ITypeBinding#getTypeUseAnnotations()
-	 */
+	@Override
 	public IAnnotationBinding[] getTypeAnnotations() {
 		if (this.typeAnnotations != null) {
 			return this.typeAnnotations;
