@@ -472,4 +472,40 @@ public interface IClasspathEntry {
 	 * @deprecated Use {@link JavaCore#getResolvedClasspathEntry(IClasspathEntry)} instead
 	 */
 	IClasspathEntry getResolvedEntry();
+
+	/**
+	 * This is a convience method, that returns <code>true</code> if the extra attributes contain an attribute whose name
+	 * is {@link IClasspathAttribute#TEST} and whose value is 'true'.
+	 * 
+	 * @see #getExtraAttributes()
+	 * @see IClasspathAttribute#TEST
+	 * @return <code>true</code>, if if the extra attributes contain a attribute whose name is
+	 *         {@link IClasspathAttribute#TEST} and whose value is 'true'.
+	 * @since 3.14
+	 */
+	default public boolean isTest() {
+		for (IClasspathAttribute attribute : getExtraAttributes()) {
+			if (IClasspathAttribute.TEST.equals(attribute.getName()) && "true".equals(attribute.getValue())) //$NON-NLS-1$
+				return true;
+		}
+		return false;
+	}
+
+	/**
+	 * This is a convience method, that returns <code>true</code> if the extra attributes contain an attribute whose name
+	 * is {@link IClasspathAttribute#WITHOUT_TEST_CODE} and whose value is 'true'.
+	 * 
+	 * @see #getExtraAttributes()
+	 * @see IClasspathAttribute#WITHOUT_TEST_CODE
+	 * @return <code>true</code>, if if the extra attributes contain a attribute whose name is
+	 *         {@link IClasspathAttribute#WITHOUT_TEST_CODE} and whose value is 'true'.
+	 * @since 3.14
+	 */
+	default public boolean isWithoutTestCode() {
+		for (IClasspathAttribute attribute : getExtraAttributes()) {
+			if (IClasspathAttribute.WITHOUT_TEST_CODE.equals(attribute.getName()) && "true".equals(attribute.getValue())) //$NON-NLS-1$
+				return true;
+		}
+		return false;
+	}
 }
