@@ -13,6 +13,7 @@ package org.eclipse.jdt.internal.core;
 import java.io.InputStream;
 import java.util.ArrayList;
 import java.util.HashMap;
+import java.util.Map;
 
 import org.eclipse.core.resources.*;
 import org.eclipse.core.runtime.*;
@@ -169,7 +170,7 @@ public abstract class JavaModelOperation implements IWorkspaceRunnable, IProgres
 	 * Registers the given reconcile delta with the Java Model Manager.
 	 */
 	protected void addReconcileDelta(ICompilationUnit workingCopy, IJavaElementDelta delta) {
-		HashMap reconcileDeltas = JavaModelManager.getJavaModelManager().getDeltaProcessor().reconcileDeltas;
+		Map<ICompilationUnit, IJavaElementDelta> reconcileDeltas = JavaModelManager.getJavaModelManager().getDeltaProcessor().reconcileDeltas;
 		JavaElementDelta previousDelta = (JavaElementDelta)reconcileDeltas.get(workingCopy);
 		if (previousDelta != null) {
 			IJavaElementDelta[] children = delta.getAffectedChildren();
@@ -204,6 +205,7 @@ public abstract class JavaModelOperation implements IWorkspaceRunnable, IProgres
 	/**
 	 * @see IProgressMonitor
 	 */
+	@Override
 	public void beginTask(String name, int totalWork) {
 		if (this.progressMonitor != null) {
 			this.progressMonitor.beginTask(name, totalWork);
@@ -318,6 +320,9 @@ public abstract class JavaModelOperation implements IWorkspaceRunnable, IProgres
 						forceFlag ? IResource.FORCE | IResource.KEEP_HISTORY : IResource.KEEP_HISTORY,
 						getSubProgressMonitor(1));
 					setAttribute(HAS_MODIFIED_RESOURCE_ATTR, TRUE);
+				} else {
+					// we didn't delete the package, so its parent packages cannot be empty
+					break;
 				}
 			}
 		} catch (CoreException e) {
@@ -355,6 +360,7 @@ public abstract class JavaModelOperation implements IWorkspaceRunnable, IProgres
 	/**
 	 * @see IProgressMonitor
 	 */
+	@Override
 	public void done() {
 		if (this.progressMonitor != null) {
 			this.progressMonitor.done();
@@ -525,6 +531,7 @@ public abstract class JavaModelOperation implements IWorkspaceRunnable, IProgres
 	public boolean hasModifiedResource() {
 		return !isReadOnly() && getAttribute(HAS_MODIFIED_RESOURCE_ATTR) == TRUE;
 	}
+	@Override
 	public void internalWorked(double work) {
 		if (this.progressMonitor != null) {
 			this.progressMonitor.internalWorked(work);
@@ -533,6 +540,7 @@ public abstract class JavaModelOperation implements IWorkspaceRunnable, IProgres
 	/**
 	 * @see IProgressMonitor
 	 */
+	@Override
 	public boolean isCanceled() {
 		if (this.progressMonitor != null) {
 			return this.progressMonitor.isCanceled();
@@ -705,6 +713,7 @@ public abstract class JavaModelOperation implements IWorkspaceRunnable, IProgres
 	 * @see IWorkspaceRunnable
 	 * @exception CoreException if the operation fails
 	 */
+	@Override
 	public void run(IProgressMonitor monitor) throws CoreException {
 		SubMonitor oldMonitor = this.progressMonitor;
 		try {
@@ -720,7 +729,7 @@ public abstract class JavaModelOperation implements IWorkspaceRunnable, IProgres
 						// noop if aready initialized
 						JavaModelManager.getDeltaState().initializeRoots(false/*not initiAfterLoad*/);
 					}
-	
+
 					executeOperation();
 				} finally {
 					if (isTopLevelOperation()) {
@@ -731,12 +740,12 @@ public abstract class JavaModelOperation implements IWorkspaceRunnable, IProgres
 				try {
 					// reacquire delta processor as it can have been reset during executeOperation()
 					deltaProcessor = manager.getDeltaProcessor();
-	
+
 					// update JavaModel using deltas that were recorded during this operation
 					for (int i = previousDeltaCount, size = deltaProcessor.javaModelDeltas.size(); i < size; i++) {
-						deltaProcessor.updateJavaModel((IJavaElementDelta)deltaProcessor.javaModelDeltas.get(i));
+						deltaProcessor.updateJavaModel(deltaProcessor.javaModelDeltas.get(i));
 					}
-	
+
 					// close the parents of the created elements and reset their project's cache (in case we are in an
 					// IWorkspaceRunnable and the clients wants to use the created element's parent)
 					// see https://bugs.eclipse.org/bugs/show_bug.cgi?id=83646
@@ -754,7 +763,7 @@ public abstract class JavaModelOperation implements IWorkspaceRunnable, IProgres
 						}
 					}
 					deltaProcessor.resetProjectCaches();
-	
+
 					// fire only iff:
 					// - the operation is a top level operation
 					// - the operation did produce some delta(s)
@@ -833,6 +842,7 @@ public abstract class JavaModelOperation implements IWorkspaceRunnable, IProgres
 	/**
 	 * @see IProgressMonitor
 	 */
+	@Override
 	public void setCanceled(boolean b) {
 		if (this.progressMonitor != null) {
 			this.progressMonitor.setCanceled(b);
@@ -848,6 +858,7 @@ public abstract class JavaModelOperation implements IWorkspaceRunnable, IProgres
 	/**
 	 * @see IProgressMonitor
 	 */
+	@Override
 	public void setTaskName(String name) {
 		if (this.progressMonitor != null) {
 			this.progressMonitor.setTaskName(name);
@@ -856,6 +867,7 @@ public abstract class JavaModelOperation implements IWorkspaceRunnable, IProgres
 	/**
 	 * @see IProgressMonitor
 	 */
+	@Override
 	public void subTask(String name) {
 		if (this.progressMonitor != null) {
 			this.progressMonitor.subTask(name);
@@ -878,6 +890,7 @@ public abstract class JavaModelOperation implements IWorkspaceRunnable, IProgres
 	/**
 	 * @see IProgressMonitor
 	 */
+	@Override
 	public void worked(int work) {
 		if (this.progressMonitor != null) {
 			this.progressMonitor.worked(work);
