@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2018 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -58,6 +58,7 @@ protected PackageFragmentRoot(IResource resource, JavaProject project) {
 /**
  * @see IPackageFragmentRoot
  */
+@Override
 public void attachSource(IPath sourcePath, IPath rootPath, IProgressMonitor monitor) throws JavaModelException {
 	try {
 		verifyAttachSource(sourcePath);
@@ -153,6 +154,7 @@ public void attachSource(IPath sourcePath, IPath rootPath, IProgressMonitor moni
 /**
  * @see Openable
  */
+@Override
 protected boolean buildStructure(OpenableElementInfo info, IProgressMonitor pm, Map newElements, IResource underlyingResource) throws JavaModelException {
 	((PackageFragmentRootInfo) info).setRootKind(determineKind(underlyingResource));
 	return computeChildren(info, underlyingResource);
@@ -169,9 +171,8 @@ SourceMapper createSourceMapper(IPath sourcePath, IPath rootPath) throws JavaMod
 
 	return mapper;
 }
-/*
- * @see org.eclipse.jdt.core.IPackageFragmentRoot#delete
- */
+
+@Override
 public void delete(
 	int updateResourceFlags,
 	int updateModelFlags,
@@ -205,9 +206,13 @@ protected boolean computeChildren(OpenableElementInfo info, IResource underlying
 //			if (module != null && module.exists()) {
 //				vChildren.add(new ClassFile(getPackageFragment(CharOperation.NO_STRINGS), String.valueOf(TypeConstants.MODULE_INFO_NAME)));
 //			}
-			IJavaElement[] children = new IJavaElement[vChildren.size()];
-			vChildren.toArray(children);
-			info.setChildren(children);
+			if (!vChildren.isEmpty()) {
+				IJavaElement[] children = new IJavaElement[vChildren.size()];
+				vChildren.toArray(children);
+				info.setChildren(children);
+			} else {
+				info.setChildren(JavaElement.NO_ELEMENTS);
+			}
 		}
 	} catch (JavaModelException e) {
 		//problem resolving children; structure remains unknown
@@ -280,9 +285,7 @@ protected void computeFolderChildren(IContainer folder, boolean isIncluded, Stri
 	}
 }
 
-/*
- * @see org.eclipse.jdt.core.IPackageFragmentRoot#copy
- */
+@Override
 public void copy(
 	IPath destination,
 	int updateResourceFlags,
@@ -299,6 +302,7 @@ public void copy(
 /**
  * Returns a new element info for this element.
  */
+@Override
 protected Object createElementInfo() {
 	return new PackageFragmentRootInfo();
 }
@@ -306,6 +310,7 @@ protected Object createElementInfo() {
 /**
  * @see IPackageFragmentRoot
  */
+@Override
 public IPackageFragment createPackageFragment(String pkgName, boolean force, IProgressMonitor monitor) throws JavaModelException {
 	CreatePackageFragmentOperation op = new CreatePackageFragmentOperation(this, pkgName, force);
 	op.runOperation(monitor);
@@ -333,6 +338,7 @@ protected int determineKind(IResource underlyingResource) throws JavaModelExcept
  * same parent, same resources, and occurrence count.
  *
  */
+@Override
 public boolean equals(Object o) {
 	if (this == o)
 		return true;
@@ -420,6 +426,7 @@ public char[][] fullInclusionPatternChars() {
 		return null;
 	}
 }
+@Override
 public String getElementName() {
 	IResource res = resource();
 	if (res instanceof IFolder)
@@ -429,18 +436,21 @@ public String getElementName() {
 /**
  * @see IJavaElement
  */
+@Override
 public int getElementType() {
 	return PACKAGE_FRAGMENT_ROOT;
 }
 /**
  * @see JavaElement#getHandleMemento()
  */
+@Override
 protected char getHandleMementoDelimiter() {
 	return JavaElement.JEM_PACKAGEFRAGMENTROOT;
 }
 /*
  * @see JavaElement
  */
+@Override
 public IJavaElement getHandleFromMemento(String token, MementoTokenizer memento, WorkingCopyOwner owner) {
 	switch (token.charAt(0)) {
 		case JEM_PACKAGEFRAGMENT:
@@ -470,6 +480,7 @@ public IJavaElement getHandleFromMemento(String token, MementoTokenizer memento,
 /**
  * @see JavaElement#getHandleMemento(StringBuffer)
  */
+@Override
 protected void getHandleMemento(StringBuffer buff) {
 	IPath path;
 	IResource underlyingResource = getResource();
@@ -488,13 +499,14 @@ protected void getHandleMemento(StringBuffer buff) {
 	buff.append(getHandleMementoDelimiter());
 	escapeMementoName(buff, path.toString());
 	if (org.eclipse.jdt.internal.compiler.util.Util.isJrt(path.toOSString())) {
-		buff.append(getHandleMementoDelimiter());
+		buff.append(JavaElement.JEM_MODULE);
 		escapeMementoName(buff, getElementName());
 	}
 }
 /**
  * @see IPackageFragmentRoot
  */
+@Override
 public int getKind() throws JavaModelException {
 	return ((PackageFragmentRootInfo)getElementInfo()).getRootKind();
 }
@@ -515,6 +527,7 @@ int internalKind() throws JavaModelException {
 /**
  * Returns an array of non-java resources contained in the receiver.
  */
+@Override
 public Object[] getNonJavaResources() throws JavaModelException {
 	return ((PackageFragmentRootInfo) getElementInfo()).getNonJavaResources(getJavaProject(), resource(), this);
 }
@@ -522,6 +535,7 @@ public Object[] getNonJavaResources() throws JavaModelException {
 /**
  * @see IPackageFragmentRoot
  */
+@Override
 public IPackageFragment getPackageFragment(String packageName) {
 	// tolerate package names with spaces (e.g. 'x . y') (http://bugs.eclipse.org/bugs/show_bug.cgi?id=21957)
 	String[] pkgName = Util.getTrimmedSimpleNames(packageName);
@@ -555,6 +569,7 @@ protected String getPackageName(IFolder folder) {
 /**
  * @see IJavaElement
  */
+@Override
 public IPath getPath() {
 	return internalPath();
 }
@@ -565,6 +580,7 @@ public IPath internalPath() {
 /*
  * @see IPackageFragmentRoot
  */
+@Override
 public IClasspathEntry getRawClasspathEntry() throws JavaModelException {
 
 	IClasspathEntry rawEntry = null;
@@ -582,6 +598,7 @@ public IClasspathEntry getRawClasspathEntry() throws JavaModelException {
 /*
  * @see IPackageFragmentRoot
  */
+@Override
 public IClasspathEntry getResolvedClasspathEntry() throws JavaModelException {
 	IClasspathEntry resolvedEntry = null;
 	JavaProject project = (JavaProject)getJavaProject();
@@ -597,6 +614,7 @@ public IClasspathEntry getResolvedClasspathEntry() throws JavaModelException {
 }
 
 
+@Override
 public IResource resource() {
 	if (this.resource != null) // perf improvement to avoid message send in resource()
 		return this.resource;
@@ -605,6 +623,7 @@ public IResource resource() {
 /*
  * @see IJavaElement
  */
+@Override
 public IResource resource(PackageFragmentRoot root) {
 	return this.resource;
 }
@@ -612,6 +631,7 @@ public IResource resource(PackageFragmentRoot root) {
 /**
  * @see IPackageFragmentRoot
  */
+@Override
 public IPath getSourceAttachmentPath() throws JavaModelException {
 	if (getKind() != K_BINARY) return null;
 
@@ -657,6 +677,7 @@ public void setSourceMapper(SourceMapper mapper) throws JavaModelException {
 /**
  * @see IPackageFragmentRoot
  */
+@Override
 public IPath getSourceAttachmentRootPath() throws JavaModelException {
 	if (getKind() != K_BINARY) return null;
 
@@ -690,6 +711,7 @@ public IPath getSourceAttachmentRootPath() throws JavaModelException {
 /**
  * @see JavaElement
  */
+@Override
 public SourceMapper getSourceMapper() {
 	SourceMapper mapper;
 	try {
@@ -715,6 +737,7 @@ public SourceMapper getSourceMapper() {
 /**
  * @see IJavaElement
  */
+@Override
 public IResource getUnderlyingResource() throws JavaModelException {
 	if (!exists()) throw newNotPresentException();
 	return resource();
@@ -723,11 +746,13 @@ public IResource getUnderlyingResource() throws JavaModelException {
 /**
  * @see IParent
  */
+@Override
 public boolean hasChildren() throws JavaModelException {
 	// a package fragment root always has the default package as a child
 	return true;
 }
 
+@Override
 public int hashCode() {
 	return resource().hashCode();
 }
@@ -743,6 +768,7 @@ public boolean ignoreOptionalProblems() {
 /**
  * @see IPackageFragmentRoot
  */
+@Override
 public boolean isArchive() {
 	return false;
 }
@@ -750,6 +776,7 @@ public boolean isArchive() {
 /**
  * @see IPackageFragmentRoot
  */
+@Override
 public boolean isExternal() {
 	return false;
 }
@@ -773,9 +800,8 @@ protected IStatus validateOnClasspath() {
 	}
 	return new JavaModelStatus(IJavaModelStatusConstants.ELEMENT_NOT_ON_CLASSPATH, this);
 }
-/*
- * @see org.eclipse.jdt.core.IPackageFragmentRoot#move
- */
+
+@Override
 public void move(
 	IPath destination,
 	int updateResourceFlags,
@@ -792,6 +818,7 @@ public void move(
 /**
  * @private Debugging purposes
  */
+@Override
 protected void toStringInfo(int tab, StringBuffer buffer, Object info, boolean showResolvedInfo) {
 	buffer.append(tabString(tab));
 	IPath path = getPath();
@@ -811,6 +838,7 @@ protected void toStringInfo(int tab, StringBuffer buffer, Object info, boolean s
 	}
 }
 
+@Override
 protected IStatus validateExistence(IResource underlyingResource) {
 	// check whether this pkg fragment root can be opened
 	IStatus status = validateOnClasspath();
@@ -851,6 +879,7 @@ protected void verifyAttachSource(IPath sourcePath) throws JavaModelException {
 public String getClassFilePath(String classname) {
 	return classname;
 }
+@Override
 public IModuleDescription getModuleDescription() {
 	try {
 		IJavaElement[] pkgs = getChildren();
@@ -877,14 +906,13 @@ public IModuleDescription getModuleDescription() {
 			}
 		}
 	} catch (JavaModelException e) {
-		e.printStackTrace();
-		//
+		Util.log(e);
 	}
 	return null;
 }
 
 public IModuleDescription getAutomaticModuleDescription() throws JavaModelException {
-	return getAutomaticModuleDescription(getRawClasspathEntry());
+	return getAutomaticModuleDescription(getResolvedClasspathEntry());
 }
 
 IModuleDescription getAutomaticModuleDescription(IClasspathEntry classpathEntry) {
@@ -904,8 +932,13 @@ IModuleDescription getAutomaticModuleDescription(IClasspathEntry classpathEntry)
 			elementName = javaProject.getElementName();
 			break;
 	}
-	char[] moduleName = AutomaticModuleNaming.determineAutomaticModuleName(elementName, isArchive(), manifest);
-	return new AbstractModule.AutoModule(this, String.valueOf(moduleName));
+	boolean nameFromManifest = true;
+	char[] moduleName = AutomaticModuleNaming.determineAutomaticModuleNameFromManifest(manifest);
+	if (moduleName == null) {
+		nameFromManifest = false;
+		moduleName = AutomaticModuleNaming.determineAutomaticModuleNameFromFileName(elementName, true, isArchive());
+	}
+	return new AbstractModule.AutoModule(this, String.valueOf(moduleName), nameFromManifest);
 }
 
 /** @see org.eclipse.jdt.internal.compiler.env.IModulePathEntry#hasCompilationUnit(String, String) */
