@@ -1,10 +1,10 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2018 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
- *
+ * 
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *******************************************************************************/
@@ -26,10 +26,12 @@ import org.eclipse.jdt.core.IType;
 import org.eclipse.jdt.core.ITypeParameter;
 import org.eclipse.jdt.core.JavaModelException;
 import org.eclipse.jdt.core.Signature;
-import org.eclipse.jdt.core.compiler.*;
+import org.eclipse.jdt.core.compiler.CategorizedProblem;
+import org.eclipse.jdt.core.compiler.CharOperation;
 import org.eclipse.jdt.internal.codeassist.ISelectionRequestor;
 import org.eclipse.jdt.internal.codeassist.SelectionEngine;
 import org.eclipse.jdt.internal.compiler.ast.AbstractVariableDeclaration;
+import org.eclipse.jdt.internal.compiler.ast.CastExpression;
 import org.eclipse.jdt.internal.compiler.ast.LambdaExpression;
 import org.eclipse.jdt.internal.compiler.ast.LocalDeclaration;
 import org.eclipse.jdt.internal.compiler.classfmt.ClassFileConstants;
@@ -178,6 +180,7 @@ public void acceptModule(char[] moduleName, char[] uniqueKey, int start, int end
 /**
  * Resolve the type.
  */
+@Override
 public void acceptType(char[] packageName, char[] typeName, int modifiers, boolean isDeclaration, char[] uniqueKey, int start, int end) {
 	int acceptFlags = 0;
 	int kind = modifiers & (ClassFileConstants.AccInterface|ClassFileConstants.AccEnum|ClassFileConstants.AccAnnotation);
@@ -249,12 +252,14 @@ public void acceptType(IType type) {
 /**
  * @see ISelectionRequestor#acceptError
  */
+@Override
 public void acceptError(CategorizedProblem error) {
 	// do nothing
 }
 /**
  * Resolve the field.
  */
+@Override
 public void acceptField(char[] declaringTypePackageName, char[] declaringTypeName, char[] name, boolean isDeclaration, char[] uniqueKey, int start, int end) {
 	if(isDeclaration) {
 		IType type= resolveTypeByLocation(declaringTypePackageName, declaringTypeName,
@@ -463,6 +468,16 @@ public void acceptLocalVariable(LocalVariableBinding binding, org.eclipse.jdt.in
 	}
 	LocalVariable localVar = null;
 	if(parent != null) {
+		String typeSig = null;
+		if (local.type == null || local.type.isTypeNameVar(binding.declaringScope)) {
+			if (local.initialization instanceof CastExpression) {
+				typeSig = Util.typeSignature(((CastExpression) local.initialization).type);
+			} else {
+				typeSig = Signature.createTypeSignature(binding.type.signableName(), true);
+			}
+		} else {
+			typeSig = Util.typeSignature(local.type);
+		}
 		localVar = new LocalVariable(
 				(JavaElement)parent,
 				new String(local.name),
@@ -470,7 +485,7 @@ public void acceptLocalVariable(LocalVariableBinding binding, org.eclipse.jdt.in
 				local.declarationSourceEnd,
 				local.sourceStart,
 				local.sourceEnd,
-				local.type == null ? Signature.createTypeSignature(binding.type.signableName(), true) : Util.typeSignature(local.type),
+				typeSig,
 				local.annotations,
 				local.modifiers,
 				local.getKind() == AbstractVariableDeclaration.PARAMETER);
@@ -487,6 +502,7 @@ public void acceptLocalVariable(LocalVariableBinding binding, org.eclipse.jdt.in
 /**
  * Resolve the method
  */
+@Override
 public void acceptMethod(
 		char[] declaringTypePackageName,
 		char[] declaringTypeName,
@@ -562,6 +578,7 @@ public void acceptMethod(
 /**
  * Resolve the package
  */
+@Override
 public void acceptPackage(char[] packageName) {
 	IPackageFragment[] pkgs = this.nameLookup.findPackageFragments(new String(packageName), false);
 	if (pkgs != null) {
@@ -701,6 +718,7 @@ protected void acceptMethodDeclaration(IType type, char[] selector, int start, i
 	}
 	return;
 }
+@Override
 public void acceptTypeParameter(char[] declaringTypePackageName, char[] declaringTypeName, char[] typeParameterName, boolean isDeclaration, int start, int end) {
 	IType type;
 	if(isDeclaration) {
@@ -731,6 +749,7 @@ public void acceptTypeParameter(char[] declaringTypePackageName, char[] declarin
 		}
 	}
 }
+@Override
 public void acceptMethodTypeParameter(char[] declaringTypePackageName, char[] declaringTypeName, char[] selector,int selectorStart, int selectorEnd, char[] typeParameterName, boolean isDeclaration, int start, int end) {
 	IType type = resolveTypeByLocation(declaringTypePackageName, declaringTypeName,
 			NameLookup.ACCEPT_ALL,
