@@ -37,13 +37,13 @@ import org.eclipse.core.runtime.IPath;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.Path;
 import org.eclipse.jdt.core.Flags;
-import org.eclipse.jdt.core.IClassFile;
 import org.eclipse.jdt.core.IField;
 import org.eclipse.jdt.core.IJavaElement;
 import org.eclipse.jdt.core.IJavaProject;
 import org.eclipse.jdt.core.IMember;
 import org.eclipse.jdt.core.IMethod;
 import org.eclipse.jdt.core.IModuleDescription;
+import org.eclipse.jdt.core.IOrdinaryClassFile;
 import org.eclipse.jdt.core.IPackageFragmentRoot;
 import org.eclipse.jdt.core.ISourceRange;
 import org.eclipse.jdt.core.IType;
@@ -110,6 +110,7 @@ public class SourceMapper
 			this.name = name;
 		}
 
+		@Override
 		public int hashCode() {
 			final int prime = 31;
 			int result = 1;
@@ -118,6 +119,7 @@ public class SourceMapper
 			return result;
 		}
 
+		@Override
 		public boolean equals(Object obj) {
 			if (this == obj)
 				return true;
@@ -138,6 +140,7 @@ public class SourceMapper
 				return false;
 			return true;
 		}
+		@Override
 		public String toString() {
 			StringBuffer buffer = new StringBuffer();
 			buffer.append('(').append(this.parent).append('.').append(this.name).append(')');
@@ -310,6 +313,7 @@ public class SourceMapper
 	/**
 	 * @see ISourceElementRequestor
 	 */
+	@Override
 	public void acceptImport(
 			int declarationStart,
 			int declarationEnd,
@@ -349,6 +353,7 @@ public class SourceMapper
 	/**
 	 * @see ISourceElementRequestor
 	 */
+	@Override
 	public void acceptLineSeparatorPositions(int[] positions) {
 		//do nothing
 	}
@@ -356,6 +361,7 @@ public class SourceMapper
 	/**
 	 * @see ISourceElementRequestor
 	 */
+	@Override
 	public void acceptPackage(ImportReference importReference) {
 		//do nothing
 	}
@@ -363,6 +369,7 @@ public class SourceMapper
 	/**
 	 * @see ISourceElementRequestor
 	 */
+	@Override
 	public void acceptProblem(CategorizedProblem problem) {
 		//do nothing
 	}
@@ -679,6 +686,7 @@ public class SourceMapper
 			ArrayList sortedRoots = new ArrayList(tempRoots);
 			if (size > 1) {
 				Collections.sort(sortedRoots, new Comparator() {
+					@Override
 					public int compare(Object o1, Object o2) {
 						IPath path1 = (IPath) o1;
 						IPath path2 = (IPath) o2;
@@ -745,6 +753,7 @@ public class SourceMapper
 	/**
 	 * @see ISourceElementRequestor
 	 */
+	@Override
 	public void enterType(TypeInfo typeInfo) {
 
 		this.typeDepth++;
@@ -852,6 +861,11 @@ public class SourceMapper
 	
 		// module type modifiers
 		this.moduleModifiers = moduleInfo.modifiers;
+
+		if (this.binaryTypeOrModule instanceof IModuleDescription) {
+			// categories
+			addCategories(this.binaryTypeOrModule, moduleInfo.categories);
+		}
 	}
 
 	@Override
@@ -867,6 +881,7 @@ public class SourceMapper
 	/**
 	 * @see ISourceElementRequestor
 	 */
+	@Override
 	public void enterCompilationUnit() {
 		// do nothing
 	}
@@ -874,6 +889,7 @@ public class SourceMapper
 	/**
 	 * @see ISourceElementRequestor
 	 */
+	@Override
 	public void enterConstructor(MethodInfo methodInfo) {
 		enterAbstractMethod(methodInfo);
 	}
@@ -881,6 +897,7 @@ public class SourceMapper
 	/**
 	 * @see ISourceElementRequestor
 	 */
+	@Override
 	public void enterField(FieldInfo fieldInfo) {
 		if (this.typeDepth >= 0) {
 			this.memberDeclarationStart[this.typeDepth] = fieldInfo.declarationStart;
@@ -899,6 +916,7 @@ public class SourceMapper
 	/**
 	 * @see ISourceElementRequestor
 	 */
+	@Override
 	public void enterInitializer(
 		int declarationSourceStart,
 		int modifiers) {
@@ -908,6 +926,7 @@ public class SourceMapper
 	/**
 	 * @see ISourceElementRequestor
 	 */
+	@Override
 	public void enterMethod(MethodInfo methodInfo) {
 		enterAbstractMethod(methodInfo);
 	}
@@ -924,7 +943,7 @@ public class SourceMapper
 				IType declaringType = currentType.getDeclaringType();
 				String declaringTypeName = declaringType.getElementName();
 				if (declaringTypeName.length() == 0) {
-					IClassFile classFile = declaringType.getClassFile();
+					IOrdinaryClassFile classFile = declaringType.getClassFile();
 					int length = parameterTypes != null ? parameterTypes.length : 0;
 					char[][] newParameterTypes = new char[length+1][];
 					declaringTypeName = classFile.getElementName();
@@ -1000,6 +1019,7 @@ public class SourceMapper
 	/**
 	 * @see ISourceElementRequestor
 	 */
+	@Override
 	public void exitType(int declarationEnd) {
 		if (this.typeDepth >= 0) {
 			IType currentType = this.types[this.typeDepth];
@@ -1016,6 +1036,7 @@ public class SourceMapper
 	/**
 	 * @see ISourceElementRequestor
 	 */
+	@Override
 	public void exitCompilationUnit(int declarationEnd) {
 		//do nothing
 	}
@@ -1023,6 +1044,7 @@ public class SourceMapper
 	/**
 	 * @see ISourceElementRequestor
 	 */
+	@Override
 	public void exitConstructor(int declarationEnd) {
 		exitAbstractMethod(declarationEnd);
 	}
@@ -1030,6 +1052,7 @@ public class SourceMapper
 	/**
 	 * @see ISourceElementRequestor
 	 */
+	@Override
 	public void exitField(int initializationStart, int declarationEnd, int declarationSourceEnd) {
 		if (this.typeDepth >= 0) {
 			IType currentType = this.types[this.typeDepth];
@@ -1045,6 +1068,7 @@ public class SourceMapper
 	/**
 	 * @see ISourceElementRequestor
 	 */
+	@Override
 	public void exitInitializer(int declarationEnd) {
 		// implements abstract method
 	}
@@ -1052,6 +1076,7 @@ public class SourceMapper
 	/**
 	 * @see ISourceElementRequestor
 	 */
+	@Override
 	public void exitMethod(int declarationEnd, Expression defaultValue) {
 		exitAbstractMethod(declarationEnd);
 	}
@@ -1134,18 +1159,21 @@ public class SourceMapper
 					source = getSourceForRootPath("", name); //$NON-NLS-1$
 				}
 			}
-	
-			if (source == null) {
-				computeAllRootPaths(typeOrModule);
-				if (this.rootPaths != null) {
-					loop: for (Iterator iterator = this.rootPaths.iterator(); iterator.hasNext(); ) {
-						String currentRootPath = (String) iterator.next();
-						if (!currentRootPath.equals(this.rootPath)) {
-							source = getSourceForRootPath(currentRootPath, name);
-							if (source != null) {
-								// remember right root path
-								this.rootPath = currentRootPath;
-								break loop;
+
+			if (source == null) { // proceed with automatic root path detection ...
+				// ... but not for multi-module roots
+				if (!(typeOrModule.getAncestor(IJavaElement.PACKAGE_FRAGMENT_ROOT) instanceof JrtPackageFragmentRoot)) {
+					computeAllRootPaths(typeOrModule);
+					if (this.rootPaths != null) {
+						loop: for (Iterator iterator = this.rootPaths.iterator(); iterator.hasNext(); ) {
+							String currentRootPath = (String) iterator.next();
+							if (!currentRootPath.equals(this.rootPath)) {
+								source = getSourceForRootPath(currentRootPath, name);
+								if (source != null) {
+									// remember right root path
+									this.rootPath = currentRootPath;
+									break loop;
+								}
 							}
 						}
 					}
